using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CourseEnum;
using System;
using WingInterfaceLibrary.DTO.Education;

namespace WingInterfaceLibrary.DTO.Courses
{
    /// <summary>
    /// 课程详细信息
    /// </summary>
    public class CourseInfoDetailDTO : BaseCourseInfoDTO
    {
        /// <summary>
        /// 报名学生列表
        /// </summary>
        /// <value></value>
        public IList<StudentInfoDTO> Students { get; set; } = new List<StudentInfoDTO>();

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value></value>
        public IList<BaseLabelInfoDTO> CaseLabels { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        /// <value></value>
        public IList<BaseLabelInfoDTO> CourseLabels { get; set; }

        /// <summary>
        /// 【班级List】
        /// </summary>
        /// <value></value>
        public IList<BaseUserGroupDTO> UserGroups { get; set; }

        /// <summary>
        /// 教培视频列表
        /// </summary>
        /// <value></value>
        public IList<VideoInfoDTO> CourseVideos { get; set; }

        /// <summary>
        /// 课程是否需要支付
        /// </summary>
        /// <value></value>
        public bool NeedPay { get { return Price > 0; } }

        /// <summary>
        /// 学生对于课程的状态
        /// </summary>
        ///  <value>0</value>
        public StudentCourseStatusEnum SignCourseStatus { get; set; }

        /// <summary>
        /// 学生是否支付：是-支付；否-未支付
        /// </summary>
        public bool IsPay { get; set; }
    }

    /// <summary>
    /// 基础课程信息对象
    /// </summary>
    public class BaseCourseInfoDTO
    {
        /// <summary>
        ///  课程编码
        /// </summary>
        /// <value>12334e</value>
        public string Code { get; set; }

        /// <summary>
        /// 课程名称
        /// </summary>
        /// <value>TestCourse</value>
        public string Name { get; set; }

        /// <summary>
        /// 课程简介
        /// </summary>
        ///  <value>Test course dec</value>
        public string CourseIntro { get; set; }

        /// <summary>
        /// 教师编码
        /// </summary>
        /// <value>04669519BF9544489E4DB547E1C01322</value>
        public string TeacherCode { get; set; }

        /// <summary>
        /// 教师名称
        /// </summary>
        /// <value>Test teacher name</value>
        public string TeacherName { get; set; }

        /// <summary>
        /// 封面图，课程海报
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        public string Poster { get; set; }

        /// <summary>
        /// 课程预计开始时间
        /// </summary>
        /// <value>2022-03-15T12:53:29.889Z</value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 课程时长【单位分钟】
        /// </summary>
        /// <value>120</value>
        public int Duration { get; set; }

        /// <summary>
        /// 课程分类
        /// </summary>
        /// <value>1</value>
        public CourseTypeEnum CourseType { get; set; }

        /// <summary>
        /// 课程规模类型
        /// </summary>
        /// <value>1</value>
        public CourseAudienceTypeEnum AudienceType { get; set; }

        /// <summary>
        /// 课件地址
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/0B7B494B7A7044F3ADE0FCF8C0422700.png</value>
        public string CoursewareToken { get; set; }

        /// <summary>
        /// 课程状态
        /// </summary>
        /// <value>1</value>
        public CourseStatusEnum Status { get; set; }

        /// <summary>
        /// 课程可见范围，默认所有
        /// </summary>
        /// <value>0</value>
        public CourseViewRangeEnum ViewRange { get; set; }

        /// <summary>
        /// 创建人
        /// </summary>
        /// <value>12345</value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 创建机构code
        /// </summary>
        /// <value>1234</value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        /// <value>2022-01-15T12:53:29.889Z</value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 课程价格
        /// </summary>
        /// <value>10.0</value>
        public decimal Price { get; set; }

        /// <summary>
        /// 课程标签列表
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CourseLabelCodes { get; set; }

        /// <summary>
        /// 病例标签
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CaseLabelCodes { get; set; }

        /// <summary>
        /// 班级CodeList
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> UserGroupCodes { get; set; }

        /// <summary>
        /// 教培视频Code列表
        /// </summary>
        /// <value>'12334e','12334e'</value>
        public IList<string> CourseVideoCodes { get; set; }

        /// <summary>
        /// 绑定试卷集合
        /// </summary>
        /// <value></value>     
        public IList<CourseExaminationDTO> BindExams { get; set; }

        /// <summary>
        /// 助教列表
        /// </summary>
        /// <value></value>
        public IList<StudentInfoDTO> Assistants { get; set; } = new List<StudentInfoDTO>();

        /// <summary>
        /// 参与专家列表
        /// </summary>
        /// <value></value>
        public IList<StudentInfoDTO> Experts { get; set; } = new List<StudentInfoDTO>();

        /// <summary>
        /// 是否代理商课程
        /// </summary>
        /// <value>false</value>
        public bool IsAgentCourse { get; set; }
    }


}