using WingInterfaceLibrary.Enum;
using System;
using System.Collections.Generic;

namespace WingInterfaceLibrary.DTO.LiveRoom
{
    /// <summary>
    /// 会诊成员信息
    /// </summary>
    public class LiveMemberDTO
    {
        /// <summary>
        /// 设备/用户编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string Code { get; set; } = string.Empty;

        /// <summary>
        /// 成员类型
        /// </summary>
        /// <value>1</value>
        public LiveMemberEnum MemberType { get; set; }

        /// <summary>
        /// 设备/用户姓名
        /// </summary>
        /// <value>刘医生</value>
        public string Name { get; set; } = string.Empty;

        /// <summary>
        /// 头像
        /// </summary>
        /// <value></value>
        public string HeadImageToken { get; set; }

        /// <summary>
        /// 状态
        /// </summary>
        public LiveMemberStatus Status { get; set; }

        /// <summary>
        /// 是否静音
        /// </summary>
        /// <value>false</value>
        public bool MuteOpened { get; set; } = false;

        /// <summary>
        /// 是否开启视频
        /// </summary>
        /// <value>false</value>
        public bool VideoOpened { get; set; }

        /// <summary>
        /// 直播信息
        /// </summary>
        /// <value></value>
        public LiveDataDTO LiveData { get; set; }

        /// <summary>
        /// 是否正在控制参数
        /// </summary>
        /// <value></value>
        public bool IsControllingParameter { get; set; }
        /// <summary>
        /// 首次加入时间
        /// </summary>
        /// <value></value>
        public DateTime FirstJoinTime { get; set; } = DateTime.UtcNow;
        /// <summary>
        /// 排序等级
        /// </summary>
        /// <value></value>
        public int SortLevel { get; set; }
        /// <summary>
        /// 设备画面信息
        /// </summary>
        /// <typeparam name="VideoDeviceInfoDO"></typeparam>
        /// <returns></returns>
        public List<VideoDeviceInfoDTO> VideoDeviceInfos { get; set; } = new List<VideoDeviceInfoDTO>();
        /// <summary>
        /// 用户来源
        /// </summary>
        /// <value></value>
        public LoginSource LoginSource { get; set; }
    }

    /// <summary>
    /// 设备画面信息
    /// </summary>
    public class VideoDeviceInfoDTO
    {
        /// <summary>
        /// 设备Id（比如超声机唯一码，用来表示这是超声机画面）
        /// </summary>
        /// <value></value>
        public string VideoDeviceId { get; set; }

        /// <summary>
        /// 视屏画面设备来源的类型（设备主屏或摄像头）
        /// </summary>
        /// <value></value>
        public VideoDeviceSourceTypeEnum VideoDeviceSourceType { get; set; }

        /// <summary>
        /// 实时通道数据或旁路实时通道数据（用于RTC）
        /// </summary>
        public LiveDataDTO LiveData { get; set; }
    }
}