using System;
using System.Globalization;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.MeasureEnum;

namespace WingInterfaceLibrary.DTO.Measure
{
    /// <summary>
    /// 测量结果数据
    /// 设备上传图像时 根据设备图像是否有测量数据上传
    /// 客户端获取查询图像时默认不返回此数据
    /// </summary>
    public class MeasuredResultsDTO
    {
        /// <summary>
        /// 版本号
        /// </summary>
        /// <value>1.0.0.1</value>
        public string Version { get; set; }

        /// <summary>
        /// 测量节点集合
        /// </summary>
        /// <value></value>
        public List<FetusNodeDTO> FetusNodes { get; set; }


    }
    /// <summary>
    /// 节点
    /// </summary>
    public class FetusNodeDTO
    {
        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Measure.FetusNode</value>
        public string TypeName { get; set; }
        /// <summary>
        /// 顺序
        /// </summary>
        /// <value>-1</value>
        ///  <code>0</code>
        public string FetusIndex { get; set; }
        /// <summary>
        /// 节点子项集合
        /// </summary>
        /// <value></value>
        public List<ChildrenFetusNodeDTO> Children { get; set; }
    }
    /// <summary>
    /// 节点子项
    /// </summary>
    public class ChildrenFetusNodeDTO
    {
        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Measure.FetusNode</value>
        public string TypeName { get; set; }
        /// <summary>
        ///测量文件夹名称
        /// </summary>
        /// <value>General</value>
        public string FolderName { get; set; }
        /// <summary>
        ///测量文件夹描述
        /// </summary>
        /// <value>General</value>
        /// <code>0</code>
        public string FolderDescription { get; set; }
        /// <summary>
        ///测量模式名称
        /// </summary>
        /// <value>2D</value>
        public string ModeName { get; set; }
        /// <summary>
        ///应用Id
        /// </summary>
        /// <value>Adult1</value>
        public string ApplicationId { get; set; }
        /// <summary>
        ///应用名称
        /// </summary>
        /// <value>Cardiac</value>
        /// <code>0</code>
        public string Application { get; set; }
        /// <summary>
        /// 测量子集合Json
        /// </summary>
        /// <value>["{ \"TypeName\": \"CustomCalculatorFeatureDTO\", \"Creator\": \"LVEDV(A4C Simp)\",   \"Guid\": \"7e9409ca-0418-4cd3-93c4-85832ba3520d\",  }"]</value>
        public List<string> Children { get; set; }
    }
    /// <summary>
    /// 测量数据
    /// </summary>
    public class MeasuredFeatureDTO
    {
        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Measure.StraightLineFeature</value>
        public virtual string TypeName { get; set; }
        /// <summary>
        /// 创建者
        /// </summary>
        /// <value>Distance</value>
        /// <code>0</code>
        public string Creator { get; set; }
        /// <summary>
        /// Guid
        /// </summary>
        /// <value>7e9409ca-0418-4cd3-93c4-85832ba3520d</value>
        public string Guid { get; set; }
        /// <summary>
        /// 是否显示
        /// </summary>
        /// <value>true</value>
        /// <code>0</code>
        public bool ShowChildFeatures { get; set; }
        /// <summary>
        /// 时间
        /// </summary>
        /// <value></value>
        /// <code>0</code>
        public DateTime TimeStamp { get; set; }
        /// <summary>
        /// 是否自动测量
        /// </summary>
        /// <value>true</value>
        /// <code>0</code>
        public bool IsAutoCalculated { get; set; }
        /// <summary>
        /// 测量数值集合
        /// </summary>
        /// <value></value>
        public List<MeasuredValueDTO> Values { get; set; }
        /// <summary>
        /// 测量Feature集合
        /// </summary>
        /// <value></value>
        public List<MeasuredFeatureDTO> ChildFeatures { get; set; }

    }
    /// <summary>
    /// 测量数值
    /// </summary>
    public class MeasuredValueDTO
    {
        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Measure.StraightLineFeature</value>
        public string TypeName { get; set; }

        /// <summary>
        /// 名称
        /// </summary>
        /// <value>Distance</value>
        ///  <code>0</code>
        public string Name { get; set; }

        /// <summary>
        /// 描述
        /// </summary>
        /// <value>Distance</value>
        ///  <code>0</code>
        public string Description { get; set; }

        /// <summary>
        /// 是否关联工作表
        /// </summary>
        /// <value></value>
        ///  <code>0</code>
        public bool WorksheetAffinity { get; set; }
        /// <summary>
        /// 描述简称
        /// </summary>
        /// <value>D</value>
        ///  <code>0</code>
        public string BriefDescription { get; set; }

        /// <summary>
        /// 数值
        /// </summary>
        /// <value>22.58</value>
        ///  <code>0</code>
        public string Value { get; set; }

        /// <summary>
        /// 单位
        /// </summary>
        /// <value>10</value>
        ///  <code>0</code>
        public Unit Unit { get; set; }

        /// <summary>
        ///目标单位
        /// </summary>
        /// <value>10</value>
        ///  <code>0</code>
        public Unit TargetUnit { get; set; }
    }
    /// <summary>
    /// 坐标点数值
    /// </summary>
    public class PointDTO
    {
        /// <summary>
        /// x轴上数值
        /// </summary>
        /// <value>-11.8984573576828</value>
        ///  <code>0</code>
        public double x { get; set; }
        /// <summary>
        /// y轴上数值
        /// </summary>
        /// <value>2.80014851119276</value>
        ///  <code>0</code>
        public double y { get; set; }
    }


}