using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;

namespace WingInterfaceLibrary.DTO.Message
{
    /// <summary>
    /// 消息DTO实体
    /// </summary>
    public class MessageInfoDTO : BaseDTO
    {
        /// <summary>
        /// 通知类型
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string Code   { get; set; }

        /// <summary>
        /// 通知类型
        /// </summary>
        /// <value>1</value>
        public NotificationTypeEnum NotificationType   { get; set; }

        /// <summary>
        /// 通知内容  json字符串
        /// </summary>
        /// <value>李医生给你发来了预约会诊的申请，请及时处理</value>
        public string Content { get; set; }

        /// <summary>
        /// 服务器地址【记录那台服务器触发的】
        /// </summary>
        /// <value>192.168.6.62</value>
        public string ServerHost { get; set; }

        /// <summary>
        /// 通知时间
        /// </summary>
        /// <value>2022-09-29 10:00:00</value>
        public DateTime NotifyTime { get; set; }

        /// <summary>
        /// 接收方类型【客户端、设备端】
        /// </summary>
        /// <value>0</value>
        public ApplicantTypeEnum ReceiverType { get; set; }

        /// <summary>
        /// 业务类型【会诊、聊天会话、公告】
        /// </summary>
        /// <value>1</value>
        public TransactionTypeEnum TransactionType  { get; set; }

        /// <summary>
        /// 关联业务编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string RelevanceCode  { get; set; }
        
        /// <summary>
        /// 关联客户信息列表
        /// </summary>
        /// <value></value>
        public IList<ClientInfoDTO> ClientInfos  { get; set; }
    }

    /// <summary>
    /// 关联客户信息
    /// </summary>
    public class ClientInfoDTO
    {
        /// <summary>
        /// 客户id (User code , admin code or device code)
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string ClientId { get; set; }

        /// <summary>
        /// 客户名称
        /// </summary>
        /// <value>张三</value>
        public string Name { get; set; }

        /// <summary>
        /// 是否已读：默认false-表示未读
        /// </summary>
        /// <value>false</value>
        public bool IsReaded { get; set; }

        /// <summary>
        /// 送达时间
        /// </summary>
        /// <value>机构描述</value>
        /// <value>2022-09-29 10:00:00</value>
        public DateTime DeliveryTime { get; set; }

        /// <summary>
        /// 已读时间
        /// </summary>
        /// <value>2022-09-29 10:00:00</value>
        public DateTime ReadTime { get; set; }
    }
}