using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Record
{
    public class RecordInfoDTO : BaseDTO
    {
        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value></value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 病人编码
        /// </summary>
        public string PatientCode { get; set; }

        /// <summary>
        /// 设备编码
        /// </summary>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 检查状态
        /// </summary>
        public RecordStatusEnum RecordStatus { get; set; }

        /// <summary>
        /// 检查医生
        /// </summary>
        /// <value></value>
        public string CreatorCode { get; set; }

        /// <summary>
        /// 处理标识，用来做特殊处理标识
        /// </summary>
        public string Tags { get; set; }

        /// <summary>
        /// 创建方式
        /// </summary>
        /// <value></value>
        public RecordCreateTypeEnum CreateType { get; set; }

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <code>0</code>
        public List<DataItemDTO> PatientInfo { get; set; }

        /// <summary>
        /// 病人额外信息列表
        /// </summary>
        /// <value></value>
        public List<PatientInfoExt> PatientInfoExtList { get; set; }

        /// <summary>
        /// 设备病人ID
        /// </summary>
        /// <value></value>
        public string DevicePatientID { get; set; }

        /// <summary>
        /// 类型
        /// </summary>
        /// <value>Person、Animals</value>
        public string PatientType { get; set; }

        /// <summary>
        /// 已读用户列表
        /// </summary>
        /// <value>"test01","test02"</value>
        public List<string> ReadUsers { get; set; } = new List<string>();

        /// <summary>
        /// 根组织
        /// </summary>
        /// <value></value>
        public string RootOrganizationCode { get; set; }

        /// <summary>
        /// 组织
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 关联的超声机本地上传的检查code
        /// </summary>
        /// <value></value>
        public List<string> AssociatedExamCodes { get; set; } = new List<string>();

        /// <summary>
        /// AI诊断状态
        /// </summary>
        /// <value>2</value>
        public DiagnosisStatusEnum DiagnosisStatus { get; set; }

        /// <summary>
        /// AI诊断结果
        /// </summary>
        /// <value></value>
        public List<DiagnosisInfoDTO> DiagnosisInfos { get; set; } = new List<DiagnosisInfoDTO>();
    }

    /// <summary>
    /// 检查额外信息
    /// </summary>
    public class PatientInfoExt
    {
        /// <summary>
        ///检查扫查类型
        /// </summary>
        /// <value>Routine</value>
        public string PatientScanType { get; set; }

        /// <summary>
        /// 检查额外信息内容
        /// </summary>
        /// <code>0</code>
        public List<DataItemDTO> Content { get; set; }
    }

    /// <summary>
    /// AI诊断结论
    /// </summary>
    public class DiagnosisInfoDTO
    {
        /// <summary>
        /// AI识别器官
        /// </summary>
        /// <value></value>
        public DiagnosisOrganEnum DiagnosisOrgan { get; set; }
        /// <summary>
        /// 诊断结论
        /// </summary>
        /// <value></value>
        public DiagnosisConclusionEnum Conclusion { get; set; }
        /// <summary>
        /// 报告状态
        /// </summary>
        /// <value></value>
        public DiagnosisReportStatusEnum ReportStatus { get; set; }
    }
}