using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Measure;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Record
{
    /// <summary>
    /// 扫查数据响应实体
    /// </summary>
    public class RemedicalInfoDTO : BaseDTO
    {
        /// <summary>
        /// 扫查数据编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string RemedicalCode { get; set; }

        /// <summary>
        /// 设备编号
        /// </summary>
        /// <value>DeviceInfoDO_202203161140268N2afK</value>
        public string DeviceCode { get; set; }

        /// <summary>
        /// 记录编号
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string RecordCode { get; set; }

        /// <summary>
        /// 病人扫查类型
        /// </summary>
        /// <value>甲状腺</value>
        public string PatientScanType { get; set; }

        /// <summary>
        /// ApplicationCategory
        /// </summary>
        /// <value>ABD</value>
        public string ApplicationCategory { get; set; }

        /// <summary>
        /// ApplicationName
        /// </summary>
        /// <value>Abd General</value>
        public string Application { get; set; }

        /// <summary>
        /// 设备上传图片-上传图片
        /// </summary>
        /// <value></value>
        public TerminalImageDTO TerminalImages { get; set; } = new TerminalImageDTO();

        /// <summary>
        /// 文件数据类型
        /// </summary>
        /// <value>0</value>
        public RemedicalFileDataTypeEnum FileDataType { get; set; }

        /// <summary>
        /// AI识别部位及图像位置描述
        /// </summary>
        /// <value>0</value>
        public ImageLocationDTO ImageLocation { get; set; }

        /// <summary>
        /// AI诊断结论
        /// </summary>
        /// <value></value>
        public DiagnosisConclusionEnum DiagnosisConclusion { get; set; }

        /// <summary>
        /// AI诊断详情
        /// </summary>
        /// <value></value>
        public string DiagnosisResult { get; set; }

        /// <summary>
        /// AI识别的器官
        /// </summary>
        /// <value></value>
        public List<DiagnosisOrganEnum> DiagnosisOrgans { get; set; } = new List<DiagnosisOrganEnum>();
        /// <summary>
        /// 测量结果数据
        /// </summary>
        /// <value></value>
        public MeasuredResultsDTO MeasuredResult { get; set; }
        /// <summary>
        /// 注释结果数据
        /// </summary>
        /// <value></value>
        public ScanImageDTO CommentResult { get; set; }

        /// <summary>
        /// 颈动脉结果
        /// </summary>
        /// <value></value>
        public CarotidResultDTO CarotidResult { get; set; }

        /// <summary>
        /// 业务类型
        /// </summary>
        /// <value></value>
        public BusinessTypeEnum BusinessType { get; set; }
    }


    /// <summary>
    /// 扫查图像数据
    /// </summary>
    public class TerminalImageDTO
    {
        /// <summary>
        /// Preview url
        /// </summary>
        /// <value></value>
        public string PreviewUrl { get; set; }

        /// <summary>
        /// CND高清图下载地址
        /// </summary>
        /// <value></value>
        public string ImageUrl { get; set; }

        /// <summary>
        /// 第一帧大图url
        /// </summary>
        public string CoverImageUrl { get; set; }

        /// <summary>
        /// 推荐下载模式 
        /// 源站或者CDN地址
        /// </summary>
        /// <value>1</value>
        public RecommendedDownloadModeEnum RecommendedDownloadMode { get; set; }

        /// <summary>
        /// 源站高清图下载地址
        /// </summary>
        /// <value></value>
        public string OriginImageUrl { get; set; }

        /// <summary>
        /// 图像大小
        /// </summary>
        /// <value>1233445</value>
        public long ImageSize { get; set; }

    }

    /// <summary>
    /// 图像位置数据
    /// </summary>
    public class ImageLocationDTO
    {
        /// <summary>
        /// 扫查图片部位类型
        /// </summary>
        public string Group { get; set; }

        /// <summary>
        /// 定位信息
        /// </summary>
        public string Position { get; set; }

        /// <summary>
        /// 象限信息
        /// </summary>
        public string Quadrant { get; set; }
    }

    public class CarotidResultDTO
    {
        public CarotidScanTypeEnum CarotidScanType { get; set; }
        public CarotidScanDirectionEnum CarotidScanDirection { get; set; }

        /// <summary>
        /// 源站SurfaceFile下载地址
        /// </summary>
        /// <value></value>
        public string SurfaceFile { get; set; } = string.Empty;
        /// <summary>
        /// CDNSurfaceFile下载地址
        /// </summary>
        /// <value></value>
        public string CDNSurfaceFile { get; set; }

        /// <summary>
        /// SurfaceFile大小
        /// </summary>
        /// <value></value>
        public long SurfaceFileSize { get; set; }
        /// <summary>
        /// 源站MdlFile下载地址
        /// </summary>
        /// <value></value>
        public string MdlFile { get; set; } = string.Empty;
        /// <summary>
        /// CDNMdlFile下载地址
        /// </summary>
        /// <value></value>
        public string CDNMdlFile { get; set; }
        /// <summary>
        ///MdlFile大小
        /// </summary>
        /// <value>123333</value>
        public long MdlFileSize { get; set; }
        public List<MeasureImageFileDTO> MeasureImageFiles { get; set; } = new List<MeasureImageFileDTO>();
        public string MeasureResult { get; set; } = string.Empty;
        public List<string> SurfaceImageList { get; set; } = new List<string>();

        /// <summary>
        /// 推荐下载模式 
        /// 源站或者CDN地址
        /// </summary>
        /// <value>1</value>
        public RecommendedDownloadModeEnum RecommendedDownloadMode { get; set; }
    }

    public class MeasureImageFileDTO
    {
        public CarotidAIImageTypeEnum ImageType { get; set; }
        public string ImageFile { get; set; } = string.Empty;
    }
}