using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.Report
{
    /// <summary>
    /// 报告实体
    /// </summary>
    public class ReportDTO : ReportBaseDTO
    {
        /// <summary>
        /// 报告模板Json
        /// </summary>
        /// <value>{\"Id":\"2013ff22-1147-4d67-9fb3-d6ec1f28d39e\",\"Name\":\"常规\"}</value>
        public string ReportTemplateJson { get; set; } = string.Empty;

        /// <summary>
        /// 报告内容Json
        /// </summary>
        /// <value>[{\"Key\":\"PatientId\",\"Value\":\"321283199103021215\"},{\"Key\":\"PatientName\",\"Value\":\"苏灿\"}]</value>
        public string ReportDatasJson { get; set; } = string.Empty;

        /// <summary>
        /// 加密病人名称
        /// </summary>
        /// <value></value>
        public string EncryptPatientName { get; set; } = "";

        /// <summary>
        /// 是否可以编辑报告
        /// </summary>
        /// <value></value>
        public bool CanEditReport { get; set; }
    }

    /// <summary>
    /// 报告实体-不含报告模板和内容
    /// </summary>
    public class ReportBaseDTO : BaseDTO
    {
        /// <summary>
        /// 报告编码
        /// </summary>
        /// <value>ReportCode_20220107104236xiP0nz</value>
        public string ReportCode { get; set; } = string.Empty;

        /// <summary>
        /// 检查编码
        /// </summary>
        /// <value>RecordInfoDO_202205111056024lshF5</value>
        public string RecordCode { get; set; } = string.Empty;

        /// <summary>
        /// 报告医生
        /// </summary>
        /// <value>UserInfoDO_20220512085239q5PuMr</value>
        public string ReportUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>DeviceInfoDO_202203161140268N2afK</value>
        public string DeviceCode { get; set; } = string.Empty;

        /// <summary>
        /// 病人Code
        /// </summary>
        /// <value>PatientInfoDO_202203161140268N2afK</value>
        public string PatientCode { get; set; } = string.Empty;

        /// <summary>
        /// 病人Id
        /// </summary>
        /// <value>321283199103021215</value>
        public string PatientId { get; set; } = string.Empty;

        /// <summary>
        /// 病人姓名
        /// </summary>
        /// <value>苏灿</value>
        public string PatientName { get; set; } = string.Empty;

        /// <summary>
        /// 报告标签
        /// </summary>
        /// <value>"良性","脂肪肝"</value>
        public List<string> ReportLabels { get; set; } = new List<string>();

        /// <summary>
        /// 来源标签
        /// </summary>
        /// <value>"Flyinsono","PC","RemoteDiagnosis"</value>
        public List<string> PlatformLabels { get; set; } = new List<string>();

        /// <summary>
        /// 诊断标签
        /// </summary>
        /// <value>"AI","Carcinoid"</value>
        public List<string> DiagnosisLabels { get; set; } = new List<string>();

        /// <summary>
        /// 检查器官
        /// </summary>
        /// <value>2</value>
        public DiagnosisOrganEnum ReportOrgan { get; set; }

        /// <summary>
        /// 报告时间
        /// </summary>
        /// <value>2022-02-28T09:21:38.861Z</value>
        public DateTime ReportTime => UpdateTime;

        /// <summary>
        /// 报告医生
        /// </summary>
        /// <value>张医生</value>
        public string ReportUserName { get; set; } = string.Empty;

        /// <summary>
        /// 报告预览图
        /// </summary>
        /// <value>http://*****.jpg</value>
        public List<ReportPreviewDTO> ReportPreviewList { get; set; } = new List<ReportPreviewDTO>();

        /// <summary>
        /// 转诊记录编码
        /// </summary>
        /// <value>ReferralRecordCode_***</value>
        public string ReferralRecordCode { get; set; } = string.Empty;

        /// <summary>
        /// 业务类型
        /// </summary>
        /// <value>0</value>
        public ReportTypeEnum ReportType { get; set; } = ReportTypeEnum.RemoteDiagnosis;
    }

    public class ReportPreviewDTO
    {
        /// <summary>
        /// 文件地址
        /// </summary>
        /// <value>http://*****.jpg</value>
        public string FileToken { get; set; }

        /// <summary>
        /// 缩略图
        /// </summary>
        /// <value>http://*****.jpg</value>
        public string ThumbnailToken { get; set; }

        /// <summary>
        /// 语言，可为空-医师报告
        /// </summary>
        /// <value></value>
        public string Language { get; set; }

        /// <summary>
        /// 文件类型
        /// </summary>
        /// <value>10</value>
        public UploadFileTypeEnum FileType { get; set; }
    }
}