using System.Collections.Generic;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.DTO.User
{
    /// <summary>
    /// 用户信息响应实体
    /// </summary>
    public class UserDTO : UserBaseDTO
    {
        /// <summary>
        /// 手机号
        /// </summary>
        /// <value>13301543825</value>
        public string Phone { get; set; } = string.Empty;

        /// <summary>
        /// 邮箱地址
        /// </summary>
        /// <value>warr.qian@vinno.com</value>
        public string Email { get; set; } = string.Empty;

        /// <summary>
        /// 用户昵称
        /// </summary>
        /// <value>打到伏地魔</value>
        public string NickName { get; set; } = string.Empty;

        /// <summary>
        /// 用户姓名
        /// </summary>
        /// <value>哈利波特</value>
        public string FullName { get; set; } = string.Empty;

        /// <summary>
        /// 所属组织
        /// </summary>
        /// <value>Org000001</value>
        public string OrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 所属组织名称
        /// </summary>
        /// <value>组织00001</value>
        public string OrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 所属顶级组织
        /// </summary>
        /// <value>RootOrg000001</value>
        public string RootOrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 所属顶级组织名称
        /// </summary>
        /// <value>机构00001</value>
        public string RootOrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 所属权限组
        /// </summary>
        /// <value>"权限1","权限1"</value>
        public List<string> AuthorityGroups { get; set; } = new List<string>();

        /// <summary>
        /// 绑定设备列表
        /// </summary>
        /// <value>"设备1","设备2"</value>
        public List<string> BindDevices { get; set; } = new List<string>();

        /// <summary>
        /// 最后使用IP地址
        /// </summary>
        /// <value>127.0.0.1</value>
        public string LastIP { get; set; }

        /// <summary>
        /// 登录次数
        /// </summary>
        /// <value></value>
        /// <value>0</value>
        public int Logintimes { get; set; }

        /// <summary>
        /// 用户状态
        /// </summary>
        /// <value>1</value>
        public UserInfoStateEnum UserState { get; set; } = UserInfoStateEnum.Activated;

        /// <summary>
        /// 用户角色列表
        /// </summary>
        /// <value>"角色1","角色2"</value>
        public List<string> RoleCodes { get; set; } = new List<string>();

        /// <summary>
        /// 用户职称列表
        /// </summary>
        /// <value>"职称1","职称2"</value>
        public List<string> RankCodes { get; set; } = new List<string>();

        /// <summary>
        /// 岗位身份列表
        /// </summary>
        /// <value>"岗位1","岗位2"</value>
        public List<string> PositionCodes { get; set; } = new List<string>();

        /// <summary>
        /// 申请状态
        /// </summary>
        /// <value>1</value>
        public ApplyStateEnum ApplyState { get; set; }

        /// <summary>
        /// 用户职称名称
        /// </summary>
        /// <value></value>
        /// <value>Rank0001</value>
        public string RankName { get; set; } = string.Empty;

        /// <summary>
        /// 岗位身份名称
        /// </summary>
        /// <value></value>
        /// <value>role0001</value>
        public string PositionName { get; set; } = string.Empty;

        /// <summary>
        /// 是否机构负责人
        /// </summary>
        /// <value></value>
        public bool IsDirector { get; set; } = false;

        /// <summary>
        /// 擅长领域
        /// </summary>
        /// <value>"test1","test2"</value>
        public List<string> FieldList { get; set; } = new List<string>();

        /// <summary>
        /// 删除的病人code集合
        /// </summary>
        /// <value>"PatientInfoDO_202205120238579oWImY","PatientInfoDO_202205120238579oWGb4"</value>
        public List<string> DeletePatientCodes { get; set; } = new List<string>();

        /// <summary>
        /// 是否开启分时诊断数据批量导出
        /// </summary>
        /// <value>false</value>
        public bool IsBatchExportDiagnoseData { get; set; }

        /// <summary>
        /// 助理用户编码
        /// </summary>
        /// <value></value>
        public string BindAssistantUserCode { get; set; }

        /// <summary>
        /// 助理医师用户编码
        /// </summary>
        /// <value></value>
        public string BindAssistantDoctorUserCode { get; set; }

        /// <summary>
        /// 登录锁定信息
        /// </summary>
        /// <value></value>
        public LoginLockInfoDTO LoginLockInfo { get; set; }

        /// <summary>
        /// 签名
        /// </summary>
        public string Signature { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        public string Language { get; set; }

        /// <summary>
        /// 报告标签
        /// </summary>
        /// <value></value>
        public bool EnableReportLabel { get; set; }
    }

    /// <summary>
    /// 用户信息响应实体
    /// </summary>
    public class UserBaseDTO : BaseDTO
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string UserCode { get; set; }

        /// <summary>
        /// 用户名
        /// </summary>
        /// <value>User_20220107104236xiP0nz</value>
        public string UserName { get; set; }

        /// <summary>
        /// 头像
        /// </summary>
        /// <value>http://192.168.6.91:9001/Storage/f5ca4b07ffd312gd2f042d88fb6bbda13c61fa6_7_0.PNG</value>
        public string HeadImageUrl { get; set; } = string.Empty;
    }

    public class UserInfoByCodeDTO : UserDTO
    {
        /// <summary>
        /// 助理用户名称
        /// </summary>
        /// <value></value>
        public string BindAssistantUserName { get; set; }

        /// <summary>
        /// 助理医师用户名称
        /// </summary>
        /// <value></value>
        public string BindAssistantDoctorUserName { get; set; }
    }

}