using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using System;

namespace WingInterfaceLibrary.DTO.User
{
    public class UserPasswordDTO : BaseDTO
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        public string UserCode { get; set; }

        /// <summary>
        /// 用户名
        /// </summary>
        public string UserName { get; set; }

        /// <summary>
        /// 密码
        /// </summary>
        public string SecretPassword { get; set; }

        /// <summary>
        /// 手机号
        /// </summary>
        public string Phone { get; set; } = string.Empty;

        /// <summary>
        /// 邮箱地址
        /// </summary>
        public string Email { get; set; } = string.Empty;

        /// <summary>
        /// 用户昵称
        /// </summary>
        public string NickName { get; set; } = string.Empty;

        /// <summary>
        /// 用户姓名
        /// </summary>
        public string FullName { get; set; } = string.Empty;

        /// <summary>
        /// 头像
        /// </summary>
        public string HeadImageUrl { get; set; } = string.Empty;

        /// <summary>
        /// 所属组织
        /// </summary>
        public string OrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 所属顶级组织
        /// </summary>
        public string RootOrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 所属权限组
        /// </summary>
        public List<string> AuthorityGroups { get; set; } = new List<string>();

        /// <summary>
        /// 绑定设备列表
        /// </summary>
        public List<string> BindDevices { get; set; } = new List<string>();

        /// <summary>
        /// 最后使用IP地址
        /// </summary>
        public string LastIP { get; set; }

        /// <summary>
        /// 登录次数
        /// </summary>
        /// <value></value>
        public int Logintimes { get; set; }

        /// <summary>
        /// 用户状态
        /// </summary>
        /// <value></value>
        public UserInfoStateEnum UserState { get; set; } = UserInfoStateEnum.Nonactivated;

        /// <summary>
        /// 用户角色列表
        /// </summary>
        /// <value></value>
        public List<string> RoleCodes { get; set; } = new List<string>();

        /// <summary>
        /// 用户职称列表
        /// </summary>
        /// <value></value>
        public List<string> RankCodes { get; set; } = new List<string>();

        /// <summary>
        /// 岗位身份列表
        /// </summary>
        /// <value></value>
        public List<string> PositionCodes { get; set; } = new List<string>();

        /// <summary>
        /// 申请状态
        /// </summary>
        public ApplyStateEnum ApplyState { get; set; }

        /// <summary>
        /// 擅长领域
        /// </summary>
        /// <value>"test1","test2"</value>
        public List<string> FieldList { get; set; } = new List<string>();

        /// <summary>
        /// 删除的病人code集合
        /// </summary>
        /// <value>"PatientInfoDO_202205120238579oWImY","PatientInfoDO_202205120238579oWGb4"</value>
        public List<string> DeletePatientCodes { get; set; } = new List<string>();

        /// <summary>
        /// 是否开启分时诊断数据批量导出
        /// </summary>
        /// <value>false</value>
        public bool IsBatchExportDiagnoseData { get; set; }

        /// <summary>
        /// 设置助理的绑定用户编码
        /// </summary>
        /// <value></value>
        public  string  BindAssistantUserCode { get; set; }

        /// <summary>
        /// 助理医师用户编码
        /// </summary>
        /// <value></value>
        public  string  BindAssistantDoctorUserCode { get; set; }

        /// <summary>
        /// password update time
        /// </summary>
        public DateTime PasswordUpdateTime { get; set; }

        /// <summary>
        /// 密码记录列表
        /// </summary>
        public List<string> PasswordRecords { get; set; } = new List<string>();

        /// <summary>
        /// 签名
        /// </summary>
        public string Signature { get; set; }

        /// <summary>
        /// 语言
        /// </summary>
        public string Language { get; set; }

        /// <summary>
        /// 报告标签
        /// </summary>
        /// <value></value>
        public bool EnableReportLabel { get; set; }

    }
    
    /// <summary>
    ///登录失败信息 
    /// </summary>
    public class LoginLockInfoDTO
    {
        public DateTime LoginDate { get; set; }

        public int Times { get; set; }
    }
}