using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Message;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// Announcement数据服务
    /// </summary>
    public interface IAnnouncementDBService
    {
        /// <summary>
        /// 增加公告内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddAnnouncementDBAsync(AddAnnouncementDBRequest request);

        /// <summary>
        /// 根据用户Code获取公告内容列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<AnnouncementInfoDTO>> QueryAnnouncementsDBByPageAsync(QueryAnnouncementsDBRequest request);

        /// <summary>
        /// 根据公告Code获取内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<AnnouncementInfoDTO> GetAnnouncementDBAsync(GetAnnouncementDBRequest request);

        /// <summary>
        /// 更新公告内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateAnnouncementDBAsync(UpdateAnnouncementDBRequest request);

        /// <summary>
        /// 删除公告内容接口
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteAnnouncementDBByCodeAsync(string code);

        /// <summary>
        /// 根据用户Code获取公告内容列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<AnnouncementInfoDTO>> GetAnnouncementsAsync(GetAnnouncementsRequest request);
    }
}