using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Courses;
using WingInterfaceLibrary.Request.Courses;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 课程数据库服务
    /// </summary>
    public interface ICourseDBService
    {
        /// <summary>
        /// 创建新课程
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateCourseAsync(CreateCourseDBRequest request);

        /// <summary>
        /// 查询课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CourseInfoDetailDTO> FindCourseByCodeAsync(FindCourseByCodeDBRequest request);

        /// <summary>
        /// 查询课程记录列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CourseInfoDetailDTO>> FindCoursesByCodesAsync(FindCourseByCodesDBRequest request);

        /// <summary>
        /// 查询课程列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<BaseCourseInfoDTO>> FindCoursePagesAsync(FindCoursePagesDBRequest request);

        /// <summary>
        /// 查询管理后台课程列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<BaseCourseInfoDTO>> FindAdminCoursePagesAsync(FindCoursePagesDBRequest request);

        /// <summary>
        /// 删除课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteCourseByCodeAsync(DeleteCourseByCodeDBRequest request);

        /// <summary>
        /// 更新课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseAsync(UpdateCourseDBRequest request);

        /// <summary>
        /// 更新课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseBindExamsAsync(UpdateCourseBindExamsRequest request);
        

        /// <summary>
        /// 查询学生课程列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<CourseInfoDetailDTO>> FindStudentInCoursePagesAsync(FindStudentCoursePagesDBRequest request);
      
        /// <summary>
        /// 更新课程状态
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseStatusAsync(UpdateCourseStatusDBRequest request);

        /// <summary>
        /// 创建视频
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateVideoDBAsync(SaveVideoRequest request);

        /// <summary>
        /// 根据课程code查询所属视频
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<VideoInfoDTO>> FindVideosByCourseCodeDBAsync(FindVideosByCourseCodeRequest request);

        /// <summary>
        /// 查询所有视频列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<VideoInfoDTO>> FindVideosPagesDBAsync(FindVideoPagesRequest request);

        /// <summary>
        /// 删除视频，同步删除课程管理视频code
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteVideoByCodeDBAsync(DeleteVideoRequest request);

        /// <summary>
        /// 更新课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseByStudentsDBAsync(UpdateCourseByStudentsDBRequest request);

        /// <summary>
        /// 学生加入用户组
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddStudentInCourseUserGroupDBAsync(AddStudentInCourseUserGroupDBRequest request);

        /// <summary>
        /// 学习完成处理
        /// </summary>
        /// <returns></returns>
        Task<bool> StudyCompletedDBAsync(StudyCompletedDBRequest request);
    }
}