using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Dictionary;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface IDeviceInfoDBService
    {
        Task<string> CreateDictionaryItemAsync(CreateDictionaryItemDBRequest request);
        Task<bool> RemoveDictionaryItemAsync(RemoveDictionaryItemDBRequest request);
        Task<List<DictionaryDTO>> FindDictionaryItemsAsync(FindDictionaryItemsDBRequest request);

        Task<List<DictionaryDTO>> FindDictionaryItemsByParentCodeAsync(string parentCode);

        Task<PageCollection<DictionaryDTO>> FindDictionaryPagesAsync(PageFilterRequest request);

        Task<DictionaryDTO> FindDictionaryByCodeAsync(string code);

        Task<bool> UpdateDictionaryItemAsync(DictionaryDTO dictionaryDTO, string extensionData, bool canNull = false);

        Task<string> InsertDeviceInfoAsync(CreateDeviceInfoDBRequest request);
        Task<DeviceInfoDTO> FindDeviceInfoByNameAsync(string name);
        Task<DeviceInfoDTO> FindDeviceInfoByCodeAsync(string code);
        Task<DeviceInfoDTO> FindDeviceInfoByShortCodeAsync(string shortCode);
        Task<PageCollection<DeviceInfoDTO>> FindDeviceInfoPagesAsync(PageFilterRequest request);
        Task<bool> DeleteDeviceInfoByCodeAsync(string code);
        Task<bool> UpdateDeviceInfoByCodeAsync(string code, DeviceInfoDTO data, string extensionData, bool canNull = false);

        /// <summary>
        /// 根据设备code列表获取设备信息列表
        /// </summary>
        /// <param name="request">移除设备请求实体</param>
        /// <returns>设备信息列表</returns>
        Task<List<DeviceInfoDTO>> FindDeviceInfoListByCodeListAsync(List<string> codeList);

        /// <summary>
        /// 根据组织编码查询所属全部设备信息
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<List<DeviceInfoDTO>> FindDeviceInfoListByOrganizationCodeAsync(string organizationCode);

        /// <summary>
        /// 根据设备序列号查询设备
        /// </summary>
        /// <param name="serialNumber">设备序列号</param>
        /// <returns>设备信息</returns>
        Task<DeviceInfoDTO> FindDeviceInfoBySerialNumberAsync(string serialNumber);

        /// <summary>
        /// 根据设备型号code列表获取设备信息列表
        /// </summary>
        /// <param name="modelCodeList"></param>
        /// <returns></returns>
        Task<List<DeviceInfoDTO>> FindDeviceInfoListByModelCodeListAsync(List<string> modelCodeList);

        /// <summary>
        /// 查询设备列表（分页）
        /// </summary>
        /// <param name="queryRequest"></param>
        /// <returns></returns>
        Task<PageResult<ManageDeviceInfoDTO>> GetDevicePagesAsync(GetDevicePagesRequest queryRequest);

        /// <summary>
        /// 更新最近登录时间
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> UpdateLoginTimeAsync(UpdateLoginTimeDBRequest request);

        /// <summary>
        /// 查找有效设备总数量
        /// </summary>
        /// <returns></returns>
        Task<long> GetActiveDeviceCount();

        /// <summary>
        /// 更新视频设备画面信息
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> UpdateVideoDeviceInfosAsync(UpdateVideoDeviceInfosDBRequest request);

        /// <summary>
        /// 新增设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<bool> AddDeviceOutputConfigAsync(AddDeviceOutputConfigDBRequest request);

        /// <summary>
        /// 获取设备画面尺寸
        /// </summary>
        /// <returns>是否操作成功</returns>
        Task<List<DeviceOutputConfigDTO>> GetDeviceOutputConfigAsync(GetDeviceOutputConfigDBRequest request);
    }
}