using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using System.Collections.Generic;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.DiagnosisModule;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// AI应用服务
    /// </summary>
    public interface IDiagnosisModuleDBService
    {
        /// <summary>
        /// 查询AI应用集合
        /// </summary>
        /// <param name="codes"></param>
        /// <returns></returns>
        Task<List<DiagnosisModuleDTO>> FindDiagnosisModuleByCodesAsync(List<string> codes);

        /// <summary>
        /// 查询AI应用集合
        /// </summary>
        /// <param name="diagnosisModules"></param>
        /// <returns></returns>
        Task<List<DiagnosisModuleDTO>> FindDiagnosisModuleByModulesAsync(List<string> diagnosisModules);

        /// <summary>增量添加AI应用</summary>
        /// <returns></returns>
        Task<bool> UpdateDiagnosisModulesAsync(UpdateDiagnosisModulesDBRequest request);

        /// <summary>
        /// 分页查询AI应用
        /// </summary>
        /// <returns></returns>
        Task<PageResult<DiagnosisModuleDTO>> GetDiagnosisModuleByPageAsync(GetDiagnosisModuleByPageDBRequest request);

        /// <summary>开启/关闭AI应用</summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateEnableStateAsync(UpdateDiagnosisModuleEnableStateDBRequest request);

        /// <summary>
        /// 查询机构AI应用集合
        /// </summary>
        /// <returns></returns>
        Task<List<DiagnosisModuleDTO>> GetOrganizationDiagnosisModulesAsync(GetOrganizationDiagnosisModulesDBRequest request);

        /// <summary>保存机构AI应用集合</summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateOrganizationDiagnosisModulesAsync(UpdateOrganizationDiagnosisModulesDBRequest request);

        /// <summary>
        /// 查询设备AI应用集合
        /// </summary>
        /// <returns></returns>
        Task<List<DiagnosisModuleDTO>> GetDeviceDiagnosisModulesAsync(GetDeviceDiagnosisModulesDBRequest request);

        /// <summary>设置设备AI应用启用状态</summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateDeviceDiagnosisModuleStateAsync(UpdateDeviceDiagnosisModuleStateDBRequest request);
    }
}