
using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Request.Education;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 教培DB服务
    /// </summary>
    public interface IEducationDBService
    {
        /// <summary>
        /// 获取标签列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IList<CourseLabelDTO>> GetCourseLabelsDBAsync(QueryCourseLabelListRequest request);

        /// <summary>
        /// 获取所有标签列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IList<CourseLabelDTO>> GetAllCourseLabelDBAsync(QueryCourseLabelDBRequest request);

        /// <summary>
        /// 获取标签列表【可获取子标签】
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IList<CourseLabelDTO>> GetCourseLabelDBByCodesAsync(QueryCourseLabelDBRequest request);

        /// <summary>
        ///新增标签
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddCourseLabelDBAsync(CourseLabelRequest request);

        /// <summary>
        /// 修改标签
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> UpdateCourseLabelDBAsync(CourseLabelRequest request);

        /// <summary>
        /// 通过code删除标签
        /// </summary> 
        /// <param name="code">标签code</param>
        /// <param name="labelType">标签类型</param>
        /// <returns></returns>
        Task<bool> DeleteCourseLabelDBByCodeAsync(string code, LabelTypeEnum labelType);

        /// <summary>
        /// 客户端根据创建人获取创建的用户组
        /// </summary> 
        /// <param name="creatorCode">创建人code</param>
        /// <returns></returns>
        Task<IList<UserGroupDTO>> GetUserGroupListsDBByCreatorCodeAsync(string creatorCode);

        /// <summary>
        /// 根据用户组列表查询用户组信息
        /// </summary> 
        /// <param name="userGroupCodes">用户组code</param>
        /// <returns></returns>
        Task<IList<UserGroupDTO>> GetUserGroupListsDBByUserGroupCodesAsync(IList<string> userGroupCodes);

        /// <summary>
        /// 查询用户组分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<UserGroupDTO>> FindUserGroupsPagesDBAsync(QueryUserGroupPageRequest request);

        /// <summary>
        /// 根据用户组和用户code查询用户组信息
        /// </summary>
        /// <param name="userGroupCode">用户组code</param>
        /// <param name="studentKeyword">学生关键字</param>
        /// <returns></returns>
        Task<UserGroupDTO> FindUserGroupsByGroupCodeDBAsync(string userGroupCode, string studentKeyword);

        /// <summary>
        /// 新增用户组
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddUserGroupDBAsync(UserGroupRequest request);

        /// <summary>
        /// 修改用户组
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> UpdateUserGroupDBAsync(UserGroupRequest request);

        /// <summary>
        /// 删除用户组
        /// </summary> 
        /// <param name="code">用户组code</param>
        /// <returns></returns>
        Task<bool> DeleteUserGroupDBByCodeAsync(string code);

        /// <summary>
        /// 用户组新增用户
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddStudentsByGroupCodeDBAsync(UserGroupRequest request);

        /// <summary>
        /// 用户组移除用户
        /// </summary>
        /// <param name="userGroupCode">用户组code</param>
        /// <param name="studentCodes">学员code列表</param>
        /// <returns></returns>
        Task<bool> RemoveStudentsByGroupCodeDBAsync(string userGroupCode, IList<string> studentCodes);

        /// <summary>
        /// 分页查询题目列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ExaminationQuestionDTO>> FindExaminationQuestionPagesDBAsync(FindExaminationQuestionPagesDBRequest request);

        /// <summary>
        /// 根据codes查询题目列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<ExaminationQuestionDTO>> FindExaminationQuestionsByCodesDBAsync(FindExaminationQuestionsByCodesDBRequest request);

        /// <summary>
        /// 创建题目
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateExaminationQuestionDBAsync(ExaminationQuestionDTO request);

        /// <summary>
        /// 详情
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<ExaminationQuestionDTO> FindExaminationQuestionByCodeDBAsync(string code);

        /// <summary>
        /// 修改题目
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateExaminationQuestionDBAsync(ExaminationQuestionDTO request);

        /// <summary>
        /// 删除题目
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> DeleteExaminationQuestionDBAsync(string code);

        /// <summary>
        /// 新增试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddExaminationPaperAsync(AddExaminationPaperDBRequest request);

        /// <summary>
        /// 删除试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteExaminationPaperAsync(DeleteExaminationPaperDBRequest request);

        /// <summary>
        /// 修改试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateExaminationPaperAsync(UpdateExaminationPaperDBRequest request);

        /// <summary>
        /// 查询试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ExaminationPaperDTO> GetExaminationPaperAsync(GetExaminationPaperDBRequest request);

        /// <summary>
        /// 查询试卷分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ExaminationPaperDTO>> GetExaminationPaperPagesAsync(GetExaminationPaperPagesDBRequest request);

        /// <summary>
        /// 根据题目code查询试卷列表
        /// </summary>
        /// <param name="questionCode"></param>
        /// <returns></returns>
        Task<IList<ExaminationPaperDTO>> GetExaminationPaperPagesByQuestionCodeAsync(string questionCode);

        /// <summary>
        /// 查询远程考核上传图像数据列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<RemoteExaminationPageDTO>> FindRemoteExaminationListDBAsync(FindRemoteExaminationListDBRequest request);

        /// <summary>
        /// 创建远程考核上传图像数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateRemoteExaminationDTODBAsync(RemoteExaminationDTO request);

        /// <summary>
        /// 创建学生答题
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateStudentExaminationDBAsync(AddStudentExaminationDBRequest request);

        /// <summary>
        /// 更新学生答题
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateStudentExaminationDBAsync(UpdateStudentExaminationDBRequest request);

        /// <summary>
        /// 查询学生答题列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<StudentExaminationDTO>> FindStudentExaminationPagesDBAsync(FindStudentExaminationPagesDBRequest request);

        /// <summary>
        /// 查询学生答题详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<StudentExaminationDTO> FindStudentExaminationByCodeDBAsync(FindStudentExaminationByCodeDBRequest request);

        /// <summary>
        /// 删除学生答题
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteStudentExaminationByCodeDBAsync(string code);
    }
}