using System.Threading.Tasks;
using WingInterfaceLibrary.Result.Record;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request.Examine;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.DTO.LiveRoom;
using WingInterfaceLibrary.DB.Request;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 房间维护服务
    /// </summary>
    public interface ILiveRoomDBService
    {
        /// <summary>
        /// 查询房间详情
        /// </summary>
        /// <returns></returns>
        Task<LiveRoomDTO> GetLiveRoomByCodeAsync(GetLiveRoomByCodeDBRequest request);

        /// <summary>
        /// 批量查询房间详情
        /// </summary>
        /// <returns></returns>
        Task<List<LiveRoomDTO>> GetLiveRoomWithCodesAsync(GetLiveRoomWithCodesDBRequest request);

        /// <summary>
        /// 查询直播中的房间集合
        /// </summary>
        /// <returns></returns>
        Task<List<LiveRoomDTO>> GetLiveRoomsAsync(GetLiveRoomsDBRequest request);

        /// <summary>
        /// 查询业务关联房间详情
        /// </summary>
        /// <returns></returns>
        Task<LiveRoomDTO> GetBusinessLiveRoomAsync(GetBusinessLiveRoomDBRequest request);

        /// <summary>
        /// 保存房间详情
        /// </summary>
        /// <returns></returns>
        Task<string> AddOrUpdateLiveRoomAsync(AddOrUpdateLiveRoomDBRequest request);

        /// <summary>
        /// 保存用户直播状态
        /// </summary>
        /// <returns></returns>
        Task<bool> AddOrUpdateLiveMemberAsync(AddOrUpdateLiveMemberDBRequest request);

        /// <summary>
        /// 删除房间
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteLiveRoomAsync(DeleteLiveRoomDBRequest request);

        /// <summary>
        /// 记录直播观看人信息
        /// </summary>
        /// <returns></returns>
        Task<bool> AddOrUpdateViewerAsync(AddOrUpdateViewerDBRequest request);        

        /// <summary>
        /// 删除直播观看人信息
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteViewerAsync(DeleteViewerDBRequest request);
    }
}