using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request;
using System.Collections.Generic;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Result.Record;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface IRecordsInfoDBService
    {
        Task<string> InsertRecordInfoAsync(CreateRecordInfoDBRequest request);
        Task<bool> UpdateRecordInfoByCodeAsync(string code, RecordInfoDTO data, string extensionData, bool canNull = false);

        /// <summary>
        /// 删除检查
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> DeleteRecordInfoByCodeAsync(string code);

        Task<RecordInfoDTO> FindRecordInfoByCodeAsync(string code);
        Task<PageCollection<RecordInfoDTO>> FindRecordInfoPagesAsync(FindRecordInfoPagesRequest request);

        Task<PageResult<GetRecordsPageDTO>> FindFullRecordInfoPagesAsync(FindFullRecordInfoPagesRequest request);
        
        /// <summary>
        /// 查询检查记录数量
        /// </summary>
        /// <param name="request">查询检查记录数量请求实体</param>
        /// <returns></returns>
        Task<long> FindRecordInfoNumAsync(FindRecordInfoNumRequest request);

        /// <summary>
        /// 根据记录codes查询记录信息列表
        /// </summary>
        /// <param name="recordCodes">记录列表</param>
        /// <returns>信息列表</returns>
        Task<List<RecordInfoDTO>> FindRecordsByRecordCodesAsync(List<string> recordCodes);

        /// <summary>
        /// 更改指定设备上传检查记录的医院
        /// 设备主动上传检查记录的医院是设备医院
        /// </summary>
        /// <param name="deviceCodes">设备编码集合</param>
        /// <param name="newOrgCode">医院编码</param>
        /// <returns></returns>
        Task<bool> UpdateRecordsWithOrgCodeAsync(List<string> deviceCodes, string newOrgCode);

        /// <summary>
        /// 查询未完成AI诊断的检查记录
        /// </summary>
        /// <returns></returns>
        Task<List<RecordInfoDTO>> GetDiagnosisInProcessRecordAsync();
        
        /// <summary>
        /// 保存检查AI诊断结果
        /// </summary>
        /// <param name="request">保存检查AI诊断结果请求实体</param>
        /// <returns></returns>
        Task<bool> UpdateRecordDiagnosisResultAsync(UpdateRecordDiagnosisResultDBRequest request);

        /// <summary>
        /// 查询转诊配置信息
        /// </summary>
        /// <returns></returns>
        Task<ReferralRecordSettingDTO> GetReferralRecordSettingAsync(GetReferralRecordSettingDBRequest request);

        /// <summary>
        /// 保存转诊配置信息
        /// </summary>
        /// <returns></returns>
        Task<bool> UpdateReferralRecordSettingAsync(UpdateReferralRecordSettingDBRequest request);

        /// <summary>
        /// 查询对应记录中是否存在用户提交的报告
        /// </summary>
        /// <param name="recordCode">记录编码</param>
        /// <param name="userCode">用户编码</param>
        /// <returns></returns>
        Task<bool> ExistRecordReportsByUserAsync(string recordCode, string userCode);
    }
}
