using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result.Record;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.Measure;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.Request.Patient;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 分时诊断图像服务
    /// </summary>
    public interface IRemedicalDBService
    {
        /// <summary>
        /// 获取分时诊断图像服务接口列表
        /// </summary>
        Task<List<RemedicalListResult>> GetRemedicalListByRecordCodeAsync(List<string> recordCodes);

        /// <summary>
        /// 新增分时诊断图像
        /// </summary>
        /// <param name="request">新增分时诊断图像请求实体</param>
        /// <returns>图像code</returns>
        Task<string> InsertRemedicalInfoAsync(CreateRemedicalInfoDBRequest request);

        /// <summary>
        /// 获取分时诊断图像服务接口列表
        /// </summary>
        /// <returns>记录对应的数据列�returns>
        Task<List<RemedicalInfoDTO>> GetAllRemedicalListAsync();

        /// <summary>
        /// 获取分时诊断图像
        /// </summary>
        Task<RemedicalInfoDTO> GetRemedicalByCodeAsync(string code, bool existDiagnosis = true);

        /// <summary>
        /// 修改分时诊断图像
        /// </summary>
        /// <param name="code"></param>
        /// <param name="data"></param>
        /// <param name="extensionData"></param>
        /// <returns>图像code</returns>
        Task<bool> ModifyRemedicalInfoAsync(string code, RemedicalInfoDTO data, string extensionData);

        /// <summary>
        /// 查询业务编码关联所有图像
        /// </summary>
        /// <param name="recordCode"></param>
        /// <returns></returns>
        Task<List<RemedicalInfoDTO>> GetRecordRemedicalAsync(string recordCode);

        /// <summary>
        /// 保存图像AI诊断结果
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateDiagnosisResult(UpdateDiagnosisResultRequest request);

        /// <summary>
        /// 获取用户自定义测量配置项
        /// </summary>
        /// <param name="userId"></param>
        /// <returns></returns>
        Task<UserDefinedMeasureInfoDTO> GetUserDefinedMeasureInfoAsync(string userId);
        /// <summary>
        /// 保存测量设置
        /// </summary>
        /// <param name="userId"></param>
        /// <param name="measureSystemSettingDict"></param>
        /// <returns></returns>
        Task<bool> SaveMeasureSystemSettingAsync(string userId, Dictionary<string, string> measureSystemSettingDict);
        /// <summary>
        /// 保存用户自定义测量配置项请求
        /// </summary>
        /// <param name="userId"></param>
        /// <param name="UserDefinedMeasureApplicationDTO"></param>
        /// <returns></returns>
        Task<bool> SaveUserDefinedMeasureApplicationAsync(string userId, UserDefinedMeasureApplicationDTO measureApplication);
        /// <summary>
        /// 保存用户自定义注释项
        /// </summary>
        /// <param name="userId"></param>
        /// <param name="UserDefinedCommentDataDTO"></param>
        /// <returns></returns>
        Task<bool> SaveUserDefinedCommentAsync(string userId, UserDefinedCommentDataDTO userDefinedCommentDataDTO);
        /// <summary>
        /// 获取用户自定义测量配置项
        /// </summary>
        /// <param name="userId"></param>
        /// <returns></returns>
        Task<bool> UpdateUserDefinedMeasureInfoAsync(UpdateUserDefinedMeasureInfoDBRequest request);
        /// <summary>
        /// 导出诊断数据
        /// </summary>
        /// <param name="request">导出诊断数据请求实体</param>
        /// <returns></returns>
        Task<ExportRemedicalDataResult> ExportRemedicalDataDBAsync(ExportRemedicalDataDBRequest request);

        /// <summary>
        /// 创建转诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> CreateReferralRecordAsync(CreateReferralRecordDBRequest request);

        /// <summary>
        /// 修改转诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> ModifyReferralRecordAsync(CreateReferralRecordDBRequest request);

        /// <summary>
        /// 根据状态查询待处理记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ReferralRecordDTO>> GetReferralRecordList(GetReferralRecordDBRequest request);

        /// <summary>
        /// 更新转诊记录信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateReferralRecordInfo(ReferralRecordDTO request);

        /// <summary>
        /// 分页查询转诊记录列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ReferralRecordDTO>> QueryReferralRecordListAsync(QueryReferralRecordDBRequest request);
        
        /// <summary>
        /// 查询转诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReferralRecordDTO> GetReferralRecordInfoAsync(GetReferralRecordByCodeDBRequest request);

        /// <summary>
        /// 查询患者转诊历史
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ReferralRecordDTO>> GetPatientReferralRecordAsync(GetPatientReferralRecordDBRequest request);

        /// <summary>
        /// 查询转诊转入历史
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ReferralRecordDTO>> GetReferralInRecordAsync(GetReferralInRecordDBRequest request);
    }
}