using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Result.Record;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request.Examine;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Request.Report;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 报告相关服务
    /// </summary>
    public interface IReportDBService
    {
        /// <summary>
        /// 查询报告信息详情
        /// </summary>
        /// <returns></returns>
        Task<ReportDTO> GetReportByCodeAsync(GetReportByCodeDBRequest request);

        /// <summary>
        /// 查询检查关联的报告集合
        /// </summary>
        /// <returns></returns>
        Task<List<ReportDTO>> GetReportByRecordCodeAsync(GetReportByRecordCodeDBRequest request);

        /// <summary>
        /// 查询病人关联的报告集合
        /// </summary>
        /// <returns></returns>
        Task<List<ReportDTO>> GetReportByPatientCodeAsync(string patientCode);

        /// <summary>
        /// 查询检查关联的报告集合
        /// </summary>
        /// <returns></returns>
        Task<List<ReportDTO>> GetReportsByRecordCodesAsync(List<string> recordCodes);

        /// <summary>
        /// 保存报告
        /// </summary>
        /// <returns></returns>
        Task<string> SaveReportAsync(SaveReportDBRequest request);

        /// <summary>
        /// 保存报告关联标签
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveReportLabelsAsync(SaveReportLabelsDBRequest request);
        
        /// <summary>
        /// 保存报告预览图
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveReportPreviewImageAsync(SaveReportPreviewImageDBRequest request);

        /// <summary>
        /// 分页查询报告标签
        /// </summary>
        /// <returns></returns>
        Task<PageResult<ReportLabelDTO>> GetReportLabelByPageAsync(GetReportLabelByPageDBRequest request);

        /// <summary>
        /// 查询报告标签详情
        /// </summary>
        /// <returns></returns>
        Task<ReportLabelDTO> GetReportLabelByCodeAsync(GetReportLabelByCodeDBRequest request);

        /// <summary>
        /// 查询报告标签集合
        /// </summary>
        /// <returns></returns>
        Task<List<ReportLabelDTO>> GetReportLabelsAsync(GetReportLabelsDBRequest request);

        /// <summary>
        /// 删除报告标签
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteReportLabelAsync(DeleteReportLabelDBRequest request);

        /// <summary>
        /// 保存报告标签
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveReportLabelAsync(SaveReportLabelDBRequest request);


        /// <summary>
        /// 拷贝报告模板
        /// </summary>
        /// <returns></returns>
        Task<string> CopyReportTemplateAsync(string reportTemplateCode, string userCode, string organizationCode);

        /// <summary>
        /// 获取个人报告模板分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ReportTemplateDTO>> GetReportTemplatePageAsync(FindReportTemplatePagesDBRequest request);

        /// <summary>
        /// 获取机构报告模板分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ReportTemplateDTO>> GetOrgReportTemplatePageAsync(FindReportTemplatePagesDBRequest request);

        /// <summary>
        /// 添加报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> AddReportTemplateAsync(AddReportTemplateDBRequest request);

        /// <summary>
        /// 更新报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateReportTemplateAsync(UpdateReportTemplateDBRequest request);

        /// <summary>
        /// 更新报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveReportTemplateAsync(RemoveReportTemplateDBRequest request);

        /// <summary>
        /// 获取报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ReportTemplateDTO> GetReportTemplateAsync(GetReportTemplateDBRequest request);

        /// <summary>
        /// 发布报告模板
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> PublishReportTemplateAsync(string code);

        /// <summary>
        /// 获取报告模板
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<ReportTemplateDTO> GetReportTemplateByCodeAsync(string code);

        /// <summary>
        /// 添加词条项
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddThesaurusAsync(AddThesaurusDBRequest request);


        /// <summary>
        /// 更新词条项
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateThesaurusAsync(UpdateThesaurusDBRequest request);

        /// <summary>
        /// 添加词条项
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddThesaurusItemAsync(AddThesaurusItemDBRequest request);

        /// <summary>
        /// 更新词条项
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateThesaurusItemAsync(UpdateThesaurusItemDBRequest request);

        /// <summary>
        /// 删除词条库
        /// </summary>
        /// <param name="request">词条库编码/param>
        /// <returns></returns>
        Task<bool> RemoveThesaurusAsync(RemoveThesaurusDBRequest request);

        /// <summary>
        /// 删除词条项
        /// </summary>
        /// <param name="request">词条项编码/param>
        /// <returns></returns>
        Task<bool> RemoveThesaurusItemAsync(RemoveThesaurusItemDBRequest request);

        /// <summary>
        /// 获取词条库分库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ThesaurusDTO>> GetThesaurusPageAsync(GetThesaurusPageRequest request);

        /// <summary>
        /// 获取词条库分库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ThesaurusDTO>> GetOrgThesaurusPageAsync(GetThesaurusPageRequest request);

        /// <summary>
        /// 获取词条项列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetThesaurusItemsAsync(GetThesaurusItemsRequest request);

        /// <summary>
        /// 获取词条项详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ThesaurusItemDTO> GetThesaurusItemByCodeAsync(GetThesaurusItemByCodeRequest request);

        /// <summary>
        /// 分页查询系统词库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ThesaurusDTO>> GetDefaultThesaurusPageAsync(GetDefaultThesaurusPageDBRequest request);

        /// <summary>
        /// 查询词库
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<ThesaurusDTO> GetThesaurusByCodeAsync(string code);

        /// <summary>
        /// 更新词库
        /// </summary>
        /// <param name="code"></param>
        /// <param name="data"></param>
        /// <param name="extensionData"></param>
        /// <returns></returns>
        Task<bool> ModifyThesaurusAsync(string code, ThesaurusDTO data, string extensionData);

        /// <summary>
        /// 发布词库
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        Task<bool> PublishThesaurusAsync(string code);

        /// <summary>
        /// 获取词条项详情
        /// </summary>
        /// <param name="code"></param>
        /// <param name="parentItemCode"></param>
        /// <param name="keyword"></param>
        /// <param name="thesaurusItemType"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetThesaurusItemsDetailListAsync(string code, string parentItemCode, string keyword = null, ThesaurusItemTypeEnum thesaurusItemType = ThesaurusItemTypeEnum.Contents);

        /// <summary>
        /// 拷贝词条库
        /// </summary>
        /// <returns></returns>
        Task<bool> CopyThesaurusAsync(string thesaurusCode, string userCode, string organizationCode);

        /// <summary>
        /// 获取个人报告模板分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ReportTemplateDTO>> ManagementReportTemplatePageAsync(FindReportTemplatePagesDBRequest request);

        /// <summary>
        /// 查询报告信息列表
        /// </summary>
        /// <returns></returns>
        Task<List<ReportDTO>> GetReportListByCodesAsync(QueryReportsByCodesDBRequest request);

        /// <summary>
        /// 保存报告模板预览图
        /// </summary>
        /// <returns></returns>
        Task<bool> SaveReportTemplatePreviewImageAsync(SaveReportPreviewImageDBRequest request);

        /// <summary>
        /// 获取报告模板引用用户编码列表
        /// </summary>
        /// <param name="reportTemplateCode">报告模版编码</param>
        /// <returns></returns>
        Task<List<string>> GetReportTemplateUserCodesAsync(string reportTemplateCode);

        /// <summary>
        /// 获取词条库引用用户编码列表
        /// </summary>
        /// <param name="thesaurusCode">词条库编码</param>
        /// <returns></returns>
        Task<List<string>> GetThesaurusUserCodesAsync(string thesaurusCode);

        /// <summary>
        /// 验证报告模板名称是否重复
        /// </summary>
        /// <param name="request"></param>
        /// <returns>true</returns>
        Task<bool> CheckReportTemplateName(UpdateReportTemplateDBRequest request);
    }
}