﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Result.UserFeature;
using System;
using WingInterfaceLibrary.DTO.Schedule;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public interface IUserDBService
    {
        Task<string> InsertUserAsync(CreateUserInfoDBRequest request);
        Task<UserDTO> FindUserByNameAsync(string name);
        Task<UserDTO> FindUserByCodeAsync(string code);
        Task<UserDTO> FindUserAsync(FindUserRequest request);
        Task<UserPasswordDTO> FindUserPasswordByCodeAsync(string code);
        Task<UserDTO> FindUserByPhoneAsync(string phone);
        Task<UserDTO> FindUserByEmailAsync(string email);
        Task<PageCollection<UserDTO>> FindUserPagesAsync(PageFilterRequest request);
        Task<bool> DeleteUserByCodeAsync(string code);
        Task<bool> UpdateUserAsync(string code, UserPasswordDTO data, string extensionData, bool canNull = false);
        Task<long> UpdateUsersAsync(UpdateUsersDBRequest request);
        Task<List<UserDTO>> FindUserListByRoleCodeAsync(string roleCode);
        Task<List<UserDTO>> FindUsersAsync(GetUsersDBRequest request);

        /// <summary>
        /// 根据机构codes获取用户列表
        /// </summary>
        /// <param name="OrganizationCodes"></param>
        /// <returns></returns>
        Task<List<UserDTO>> FindUserListByOrganizationCodesAsync(List<string> organizationCodes);

        /// <summary>
        /// 根据codes获取用户列表
        /// </summary>
        /// <param name="codes">用户codes</param>
        /// <returns></returns>
        Task<List<UserDTO>> FindUserListByUserCodesAsync(List<string> codes);

        /// <summary>
        /// 将设备绑定到用户中
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<long> BingDevicesToUsersAsync(BingDevicesToUsersRequest request);

        /// <summary>
        /// 验证用户密码是否正确
        /// </summary>
        /// <param name="UserCode"></param>
        /// <param name="password"></param>
        /// <returns></returns>
        Task<bool> VerificationPasswordAsync(string UserCode, string password);

        /// <summary>
        /// 获取设备用户列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ManageDeviceUserDTO>> GetDeviceUserPagesAsync(GetDeviceUserPagesRequest request);

        /// <summary>
        /// 根据设备获取用户列表 
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<UserDTO>> GetUsersByDeviceAsync(string deviceCode);

        /// <summary>
        /// 根据设备Codes获取用户列表 
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<UserDTO>> GetUsersByDevicesAsync(List<string> deviceCodes);

        /// <summary>
        /// 查询机构用户列表（分页）
        /// </summary>
        /// <param name="allNeeds"></param>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ManageOrganizationUserDTO>> GetManageOrganizationUserPagesAsync(List<OrganizationDTO> allNeeds, GetOrganizationUserPagesRequest request);

        /// <summary>
        /// 根据组织、岗位身份、职称查询用户列表信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<UserDTO>> GetUserListAsync(GetUserListDBRequest request);

        /// <summary>
        /// 查找用户列表（分页）自定义条件
        /// </summary>
        /// <param name="request">分页信息</param>
        /// <returns></returns>
        Task<PageCollection<UserDTO>> FindUserPagesCustomAsync(PageFilterRequest request);

        /// <summary>
        /// 根据用户和医院名称集合查询用户列表信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageCollection<UserDTO>> FindUserPagesByOrgsAsync(FindUserPageByOrgsRequest request);

        /// <summary>
        /// 根据组织编码查找用户
        /// </summary>
        /// <param name="organizationCode"></param>
        /// <returns></returns>
        Task<List<UserDTO>> FindUsersByOrganizationCodeAsync(string organizationCode);

        /// <summary>
        /// 删除病人
        /// </summary>
        /// <returns></returns>
        Task<bool> DeletePatientsByUserCodeAsync(DeletePatientsDBRequest request);

        /// <summary>
        /// 设置用户默认词条库编码
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <param name="thesaurusCode">默认词条库编码</param>
        /// <returns></returns>
        Task<bool> SetUserDefaultThesaurusCodeAsync(string userCode, string thesaurusCode);

        /// <summary>
        /// 获取用户默认词条库编码
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <returns>词条库编码</returns>
        Task<string> GetUserDefaultThesaurusCodeAsync(string userCode);

        /// <summary>
        /// 获取用户默认词条库信息
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <returns></returns>
        Task<ThesaurusAllDTO> GetUserDefaultThesaurusContentAsync(string userCode);

        /// <summary>
        /// 设置用户默认报告模板编码
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <param name="thesaurusCode">默认报告模板编码</param>
        /// <returns></returns>
        Task<bool> SetUserDefaultReportTemplateCodeAsync(string userCode, string thesaurusCode);

        /// <summary>
        /// 获取用户默认报告模板编码
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <returns>报告模板编码</returns>
        Task<string> GetUserDefaultReportTemplateCodeAsync(string userCode);

        /// <summary>
        /// 获取用户默认报告模板信息
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <returns></returns>
        Task<ReportTemplateDTO> GetUserDefaultReportTemplateContentAsync(string userCode);

        /// <summary>查询专家助理绑定的所有专家</summary>
        /// <returns></returns>
        Task<IList<UserDTO>> GetBindExpertsAsync(string assistentCode);


        /// <summary>
        /// 根据codes获取用户列表
        /// </summary>
        /// <param name="codes"></param>
        /// <returns></returns>
        Task<List<UserPasswordDTO>> FindUsersByUserCodesAsync(List<string> codes);

        /// <summary>
        /// 更新用户登录锁定次数
        /// </summary>
        /// <param name="code"></param>
        /// <param name="loginLockInfoDTO"></param>
        /// <returns></returns>
        Task<bool> UpdateUserLoginLockInfoAsync(string code, LoginLockInfoDTO loginLockInfoDTO);
        /// <summary>
        /// 更新用户密码 
        /// </summary>
        /// <param name="code"></param>
        /// <param name="password"></param>
        /// <param name="pwdRecords"></param>
        /// <param name="updateTime"></param>
        /// <returns></returns>
        Task<bool> UpdateUserPasswordAsync(string code, string password, IList<string> pwdRecords = null, DateTime? updateTime = null);
        /// <summary>
        /// 更新用户登录信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateUserLoginInfoAsync(UpdateUserLoginInfoDBRequest request);

        /// <summary>
        /// 获取最后新增的用户的创建时间
        /// </summary>
        /// <returns></returns>
        Task<DateTime> GetLastUserCreateTime();


        Task<string> AddScheduleDBAsync(AddScheduleDBRequest request);

        Task<bool> UpdateScheduleDBAsync(UpdateScheduleDBRequest request);

        Task<bool> AddScheduleUsersDBAsync(AddScheduleUsersDBRequest request);

        Task<bool> UpdateScheduleStateDBAsync(UpdateScheduleStateDBRequest request);

        Task<bool> DeleteScheduleDBAsync(string code);

        Task<ScheduleDTO> GetScheduleDBByCodeAsync(string code);

        Task<IList<ScheduleDTO>> GetScheduleDBAsync(GetScheduleDBRequest request);

        Task<ScheduleDTO> GetScheduleDBByRelevanceCodeAsync(string code);

        /// <summary>
        /// 查找有效用户总数量
        /// </summary>
        /// <returns></returns>
        Task<long> GetActiveUsersCount();
        
        /// <summary>
        /// 通过多个角色获取用户信息
        /// </summary>
        /// <param name="roleCodes"></param>
        /// <returns></returns>
        Task<List<UserDTO>> FindUserListByRoleCodesAsync(IList<string> roleCodes);
    }
}
