﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.IdentityApply;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.User;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 用户角色服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>个人信息接口</docSecondDirectory>
    public interface IIdentityApplyService
    {
        /// <summary>
        /// 获取认证角色申请状态信息列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>认证角色状态信息列表</returns>
        /// <value></value>
        Task<List<IdentityApplyDTO>> GetIdentityApplysAsync(TokenRequest request);

        /// <summary>
        /// 获取最新认证角色申请状态信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>角色状态信息响应实体</returns>
        /// <value></value>
        Task<IdentityApplyDTO> GetLastIdentityApplyAsync(GetLastIdentityApplyRequest request);

        /// <summary>
        /// 申请认证角色
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> ApplyForAsync(ApplyForRequest request);
    }
}
