using System.Threading.Tasks;
using WingInterfaceLibrary.Request.Payment;
using WingInterfaceLibrary.DTO.Payment;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 支付服务接口
    /// </summary>
    public interface IPaymentService
    {
        /// <summary>
        /// 购买接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CreateOrderResultDTO> CreateOrderAsync(CreateOrderRequest request);

        /// <summary>
        /// 订单详情接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<OrderDetailDTO> GetOrderDetailAsync(GetOrderDetailRequest request);

        /// <summary>
        /// 订单列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<OrderDetailDTO>> GetOrderPagesAsync(GetOrderPagesRequest request);

        /// <summary>
        /// 发起支付请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PayInfoDTO> GoToPayAsync(GoToPayRequest request);

        /// <summary>
        /// 支付后回调
        /// </summary>
        /// <param name="src">来源</param>
        /// <param name="request">请求信息</param>
        /// <returns></returns>
        Task<PayCallbackDTO> PayCallbackAsync(string src,string request);
    }
}