﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Position;
using WingInterfaceLibrary.Request.User;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 岗位信息服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>个人信息接口</docSecondDirectory>
    public interface IPositionService
    {
        /// <summary>
        /// 获取岗位身份信息
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>岗位信息集合</returns>
        Task<List<PositionDTO>> GetPositionsAsync(GetPositionsRequest request);

        /// <summary>
        /// 添加岗位身份
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>PositionNameIsEmpty,PositionNameDuplicate</errorCodes>
        Task<bool> AddPositionsAsync(AddPositionsRequest request);

        /// <summary>
        /// 删除岗位身份
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> RemovePositionsAsync(RemovePositionRequest request);

        /// <summary>
        /// 更新岗位身份
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>PositionCodeIsEmpty,PositionNameIsEmpty,FitDepartmentCodeIsEmpty,PositionNameDuplicate</errorCodes>
        Task<bool> UpdatePositionNameAsync(UpdatePositionNameRequest request);
    }
}
