﻿using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Record;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Result.Record;
using System.Collections.Generic;


namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 检查记录服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>检查记录服务接口</docSecondDirectory>
    public interface IRecordInfoService
    {
        /// <summary>
        /// 创建检查记录
        /// </summary>
        /// <param name="request">创建检查请求实体</param>
        /// <returns>是否成功</returns>
        /// <errorCodes>PatientCodeIsEmpty,DeviceCodeIsEmpty,PatientNotExistError,PatientNoSameOrg,NoExistDevice,DeviceNoSameOrg</errorCodes>
        Task<bool> CreateRecordInfoAsync(CreateRecordRequest request);

        /// <summary>
        /// 分页查找检查列表
        /// </summary>
        /// <param name="request">分页查找检查列表请求实体</param>
        /// <returns>检查列表</returns>
        /// <errorCodes>PatientCodeIsEmpty,PatientNotExistError,PatientNoSameOrg</errorCodes>
        Task<PageResult<GetRecordsPageDTO>> GetRecordInfoPagesAsync(GetRecordsPageRequest request);

        /// <summary>
        /// 查询检查记录详情
        /// </summary>
        /// <param name="request">查询检查记录详情请求实体</param>
        /// <returns>检查记录详情</returns>
        /// <errorCodes>RecordCodeIsEmpty,RecordNotExistError</errorCodes>
        Task<QueryRecordResult> QueryRecordInfoAsync(QueryRecordRequest request);

        /// <summary>
        /// 查询未读检查数量
        /// </summary>
        /// <param name="request">登录人token</param>
        /// <returns>未读检查数量</returns>
        /// <value>10</value>
        /// <remarks>POST</remarks>
        Task<int> GetUnReadExamNumAsync(TokenRequest request);

        /// <summary>
        /// 动态处理检查数据接口
        /// </summary>
        /// <param name="request">动态处理检查数据请求实体</param>
        /// <returns>动态处理检查数据返回实体</returns>
        /// <errorCodes>GestationalAgeOriginIsEmpty</errorCodes>
        Task<ProcessRecordDataResult> ProcessRecordDataAsync(ProcessRecordDataRequest request);

        /// <summary>
        /// 关联检查
        /// </summary>
        /// <param name="request">关联检查i请求实体</param>
        /// <returns>返回是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>ReservationNoExistError,ExamNotExistError,RecordNoSameDevice,ExamNotRemedicalDataError</errorCodes>
        Task<bool> RelevanceRecordAsync(RelevanceRecordRequest request);

        /// <summary>
        /// 客户端完成检查
        /// </summary>
        /// <param name="request">客户端完成检查请求实体</param>
        /// <returns>返回是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>RecordNotExistError</errorCodes>
        Task<bool> FinishRecordAsync(FinishRecordRequest request);

        /// <summary>
        /// 保存客户端上传云端测量图像信息接口
        /// </summary>
        /// <param name="request">客户端完成检查请求实体</param>
        /// <returns>返回是否成功</returns>
        /// <value>true</value>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>云端测量图像服务接口</docSecondDirectory>
        /// <errorCodes>RecordNotExistError,RemedicalMeasuredInfosIsEmpty,ExamNotRemedicalDataError,FileTokenIsEmpty,LiveConsultationNotFound</errorCodes>
        Task<bool> AddRemedicalMeasuredInfoAsync(AddRemedicalMeasuredInfoRequest request);

        /// <summary>
        /// 查询客户端保存到云端测量图像信息接口
        /// </summary>
        /// <param name="request">查询客户端保存到云端测量图像信息请求实体</param>
        /// <docFirstDirectory>客户端API</docFirstDirectory>
        /// <docSecondDirectory>云端测量图像服务接口</docSecondDirectory>
        /// <errorCodes>RecordNotExistError,LiveConsultationNotFound</errorCodes>
        Task<List<RemedicalMeasuredInfoDTO>> FindRemedicalMeasuredInfoAsync(FindRemedicalMeasuredInfoRequest request);
    }
}