﻿using System.Threading.Tasks;
using WingInterfaceLibrary.Request.Examine;
using WingInterfaceLibrary.Result.Examine;
using WingInterfaceLibrary.Request.Record;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Result.Record;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Request.Device;
using WingInterfaceLibrary.Result.Organization;
using WingInterfaceLibrary.Request.Organization;
using WingInterfaceLibrary.Request.Measure;
using WingInterfaceLibrary.DTO.Measure;
using WingInterfaceLibrary.Request.Comment;
using WingInterfaceLibrary.DTO.Comment;
using WingInterfaceLibrary.DTO.Record;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.Patient;
using WingInterfaceLibrary.DTO.Patient;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Request.Management;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 分时诊断服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>分时诊断服务接口</docSecondDirectory>
    public interface IRemedicalService
    {
        /// <summary>
        /// 创建检查
        /// </summary>
        /// <param name="request">创建检查请求实体</param>
        /// <returns>创建检查结果</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>分时诊断服务接口</docSecondDirectory>
        /// <errorCodes>PatientTypeIsEmpty,DeviceNotOrg</errorCodes>
        Task<CreateExaminfoResult> CreateExamInfoAsync(CreateExaminfoRequest request);

        /// <summary>
        /// 上传检查图像
        /// </summary>
        /// <param name="request">上传检查图像请求实体</param>
        /// <returns>上传检查图像结果</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>分时诊断服务接口</docSecondDirectory>
        /// <errorCodes>ExamCodeIsEmpty,FileTokenIsEmpty,ExamNotExistError,ExamIsScaned,ExamNotForDeviceError</errorCodes>
        Task<bool> UploadExamDataAsync(UploadExamDataRequest request);

        /// <summary>
        /// 查询检查图像详情
        /// </summary>
        /// <param name="request">查询检查图像详情请求实体</param>
        /// <returns>扫查图像详情</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<RemedicalInfoDTO> FindRemedicalByCodeAsync(FindRemedicalByCodeRequest request);

        Task<bool> AddToRemedicalDiagnosisAsync(AddToRemedicalDiagnosisRequest request);

        /// <summary>
        /// 根据扫查记录获取扫查图像详情
        /// </summary>
        /// <param name="request">扫查记录请求实体</param>
        /// <returns>扫查图像列表</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeIsEmpty,RecordNotExistError,RemedicalNotExistError</errorCodes>
        Task<RemedicalListResult> GetRemedicalListByRecordInfoAsync(QueryRecordRequest request);

        /// <summary>
        /// 根据患者编号查询所有的扫查图像
        /// </summary>
        /// <param name="request">患者编号请求实体</param>
        /// <returns>扫查图像列表</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>PatientCodeIsEmpty</errorCodes>
        Task<PageResult<RemedicalListResult>> GetRemedicalListPagesAsync(GetRecordsPageRequest request);

        /// <summary>
        /// 通用数据查询接口
        /// </summary>
        /// <param name="request">通用数据查询接口请求实体</param>
        /// <returns></returns>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>分时诊断服务接口</docSecondDirectory>
        Task<List<DataItemDTO>> QueryDropdownListAsync(QueryDropdownListReuqest request);

        /// <summary>
        /// 获取机构配置信息
        /// </summary>
        /// <param name="request">获取配置信息请求实体</param>
        /// <returns></returns>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>分时诊断服务接口</docSecondDirectory>
        /// <errorCodes>VersionInvalid,GreaterThanNewestVersion,GreaterThanNewestVersion</errorCodes>
        Task<OrganizationSettingResult> GetOrganizationSettingAsync(GetUserOrganizationSettingRequest request);


        Task<QueryReservationResult> QueryReservationAsync(QueryReservationRequest request);

        /// <summary>
        /// 完成检查通知客户端
        /// </summary>
        /// <param name="request"></param>
        /// <returns>返回是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>UserCodeEmptyError,RecordCodeIsEmpty</errorCodes>
        Task<bool> PushFinshExamNotificationToClientAsync(PushFinishExamNotifyToClientRequest request);

        /// <summary>
        /// 完成检查
        /// </summary>
        /// <param name="request">设备端完成检查请求实体</param>
        /// <returns>返回是否成功</returns>
        /// <value>true</value>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>分时诊断服务接口</docSecondDirectory>
        /// <errorCodes>RecordCodeIsEmpty</errorCodes>
        Task<bool> DeviceFinishExamAsync(DeviceFinishExamRequest request);

        /// <summary>
        /// 查询检查列表
        /// </summary>
        /// <param name="request">查询检查列表请求实体</param>
        /// <returns></returns>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>分时诊断服务接口</docSecondDirectory>
        Task<PageResult<QueryExamListItemResult>> QueryExamListAsync(QueryExamListRequest request);

        /// <summary>
        /// 查询检查详情
        /// </summary>
        /// <param name="request">查询检查详情请求实体</param>
        /// <returns></returns>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>分时诊断服务接口</docSecondDirectory>
        Task<QueryExamInfoResult> QueryExamInfoAsync(QueryExamInfoRequest request);

        /// <summary>
        /// 获取测量配置项请求
        /// </summary>
        /// <param name="request">获取测量配置项请求实体</param>
        /// <returns></returns>
        /// <errorCodes>ApplicationNameIsEmpty,CategoryNameIsEmpty,MeasureModesIsNull</errorCodes>
        Task<MeasureApplicationDTO> GetMeasureApplicationAsync(GetMeasureApplicationRequest request);
        /// <summary>
        ///获取应用的注释配置项请求
        /// </summary>
        /// <param name="request">获取应用的注释配置项请求实体</param>
        /// <returns></returns>
        /// <errorCodes>LanguageCodeIsEmpty,ApplicationNameIsEmpty,CategoryNameIsEmpty</errorCodes>
        Task<CommentItemResultDTO> GetCommentsByApplicationAsync(GetCommentsByApplicationRequest request);
        /// <summary>
        ///获取预设注释配置项请求
        /// </summary>
        /// <param name="request">获取预设注释配置项请求实体</param>
        /// <returns></returns>
        /// <errorCodes>LanguageCodeIsEmpty</errorCodes>
        Task<PresetCommentItemResultDTO> GetPresetCommentsAsync(GetPresetCommentsRequest request);

        /// <summary>
        ///根据语言获取报告内容
        /// </summary>
        /// <param name="request">根据语言获取报告内容请求实体</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<string> GetReportElementByLanguageAsync(GetReportElementByLanguageRequest request);
        /// <summary>
        /// 用户自定义保存注释项请求
        /// </summary>
        /// <param name="request">用户自定义保存注释项请求实体</param>
        /// <returns></returns>
        /// <errorCodes>LanguageCodeIsEmpty,CategoryNameIsEmpty,ApplicationNameIsEmpty,CommentItemsIsNull</errorCodes>
        Task<bool> SaveUserDefinedCommentsAsync(SaveUserDefinedCommentsRequest request);
        /// <summary>
        /// 重置用户保存注释项请求
        /// </summary>
        /// <param name="request">重置用户保存注释项请求</param>
        /// <returns></returns>
        Task<bool> ResetUserCommentsAsync(ResetUserCommentsRequest request);
        /// <summary>
        /// 用户自定义保存测量配置项请求
        /// </summary>
        /// <param name="request">用户自定义保存测量配置项请求实体</param>
        /// <returns></returns>
        /// <errorCodes>CategoryNameIsEmpty,ApplicationNameIsEmpty,WorkingModeIsNull</errorCodes>
        Task<bool> SaveUserDefinedMeasureApplicationAsync(SaveUserDefinedMeasureApplicationRequest request);
        /// <summary>
        /// 获取测量系统设置请求
        /// </summary>
        /// <param name="request">获取测量系统设置请求实体</param>
        /// <returns></returns>
        Task<MeasureSystemSettingDTO> GetMeasureSystemSettingAsync(GetMeasureSystemSettingRequest request);

        /// <summary>
        /// 用户自定义保存测量系统设置请求
        /// </summary>
        /// <param name="request">用户自定义保存测量系统设置请求实体</param>
        /// <returns></returns>
        /// <errorCodes>SystemSettingIsNull</errorCodes>
        Task<bool> SaveMeasureSystemSettingAsync(SaveMeasureSystemSettingRequest request);

        /// <summary>
        /// 导出诊断数据
        /// </summary>
        /// <param name="request">导出诊断数据请求实体</param>
        /// <returns></returns>
        /// <errorCodes>PatientCodesRequired,IsBatchExportDiagnoseDataFalse</errorCodes>
        Task<ExportRemedicalDataResult> ExportRemedicalDataAsync(ExportRemedicalDataRequest request);

        /// <summary>
        /// 查询缓存内容
        /// </summary>
        /// <param name="request">查询缓存请求实体</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<string> FindCacheByCodeAsync(FindCacheByCodeRequest request);

        /// <summary>
        /// 申请转诊
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <value>true</value>
        /// <errorCodes>ExamRecordsIsEmpty,ReferralNotAccepted,CanNotReferral,ReferralIsCircle,PatientInfoIsNotValid,ExistUnCompleteScan,NoRightToReferralInThisOrg</errorCodes>
        Task<string> ApplyReferralRecordAsync(CreateReferralRecordRequest request);

        /// <summary>
        /// 修改转诊
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <value>true</value>
        /// <errorCodes>ReferralCanNotModify,ReferralNotAccepted,ReferralIsCircle,PatientInfoIsNotValid,ExistUnCompleteScan,NoRightToReferralInThisOrg</errorCodes>
        Task<string> ModifyReferralRecordAsync(ModifyReferralRecordRequest request);

        /// <summary>
        /// 转诊记录列表
        /// </summary>
        /// <param name="request">查询检查列表请求实体</param>
        /// <returns></returns>
        /// <errorCodes>StartTimeGreaterThanEndTime,NotSupportPatientState,UserNotExistError</errorCodes>
        Task<PageResult<QueryReferralRecordPageDTO>> QueryReferralRecordListAsync(QueryReferralRecordListRequest request);

        /// <summary>
        /// 转诊处理（同意、拒绝）
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <value>true</value>
        /// <errorCodes>OrganizationCodeEmpty,ReferralIsNotWait,ReferralIsTimedOut,CanNotReferral</errorCodes>
        Task<bool> AuditReferralRecordAsync(AuditReferralRecordRequest request);

        /// <summary>
        /// 撤回转诊
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <value>true</value>
        /// <errorCodes>ReferralIsNotWait,CanNotReferral</errorCodes>
        Task<bool> WithdrawReferralRecordAsync(WithdrawReferralRecordRequest request);

        /// <summary>
        /// 搜索转诊组织
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>OrganizationCodeEmpty</errorCodes>
        Task<List<OrganizationDTO>> QueryReferralOrganizationsAsync(ReferralOrganizationsQueryRequest request);

        /// <summary>
        /// 转诊病人详细信息
        /// </summary>
        /// <param name="request">获取病人信息的请求实体</param>
        /// <returns>病人详细信息实体</returns>
        /// <errorCodes>ReferralRecordCodeEmpty</errorCodes>
        Task<ClientPatientInfoDTO> QueryReferralPatientByCodeAsync(QueryReferralPatientByCodeRequest request);

        /// <summary>
        /// 查询患者转诊历史
        /// </summary>
        /// <param name="request">查询患者转诊记录请求实体</param>
        /// <returns>转诊历史</returns>
        Task<List<ReferralRecordDetailDTO>> FindPatientReferralRecordAsync(FindPatientReferralRecordRequest request);

        /// <summary>
        /// 查询转诊单转入历史
        /// </summary>
        /// <param name="request">查询转诊单转入历史请求实体</param>
        /// <returns>转诊历史</returns>
        Task<List<ReferralRecordDetailDTO>> FindReferralInRecordAsync(FindReferralInRecordRequest request);
        
        /// <summary>
        /// 转诊患者查询所有的扫查图像
        /// </summary>
        /// <param name="request">患者编号请求实体</param>
        /// <returns>扫查图像列表</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>ReferralRecordCodeEmpty</errorCodes>
        Task<PageResult<RemedicalListResult>> QueryReferralRemedicalListPagesAsync(QueryReferralRecordsPageRequest request);

        /// <summary>
        /// 分页查找转诊病人检查列表
        /// </summary>
        /// <param name="request">分页查找检查列表请求实体</param>
        /// <returns>检查列表</returns>
        /// <errorCodes>ReferralRecordCodeEmpty,PatientDataIsEmpty</errorCodes>
        Task<PageResult<GetRecordsPageDTO>> QueryReferralRecordInfoPagesAsync(QueryReferralRecordsPageRequest request);

        /// <summary>
        /// 查询转诊检查关联报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>ReferralRecordCodeEmpty</errorCodes>
        Task<List<ReportDTO>> QueryReferralExamReportsAsync(QueryReferralExamReportRequest request);

        /// <summary>
        /// 查询转诊病人关联报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>ReferralRecordCodeEmpty</errorCodes>
        Task<List<ReportDTO>> QueryReferralPatientReportsAsync(QueryReferralPatientByCodeRequest request);

        /// <summary>
        /// 根据扫查记录获取转诊扫查图像详情 
        /// </summary>
        /// <param name="request">转诊扫查记录请求实体</param>
        /// <returns>扫查图像列表</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeIsEmpty,ReferralRecordCodeEmpty,RecordNotExistError,RemedicalNotExistError</errorCodes>
        Task<RemedicalListResult> QueryReferralRemedicalListByRecordInfoAsync(QueryReferralExamReportRequest request);

        /// <summary>
        /// 获取扫查分享页面根据分享地址 
        /// </summary>
        /// <param name="request">转诊扫查记录请求实体</param>
        /// <returns>扫查图像列表</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>FileTokenIsEmpty,InitShareExamConfigError,SystemError,LanguageCodeIsEmpty</errorCodes>
        Task<QueryShareExamPageResult> QueryShareExamPageAsync(QueryShareExamPageRequest request);
    }
}
