﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Role;
using WingInterfaceLibrary.Request.User;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 用户角色
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>个人信息接口</docSecondDirectory>
    public interface IRoleService
    {
        /// <summary>
        /// 获取角色信息
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <errorCodes>RoleCodesIsEmpty,RoleNoExist,LanguageCodeIsEmpty</errorCodes>
        /// <returns>角色信息</returns>
        Task<RoleDTO> GetRoleByCodeAsync(GetRoleByCodeRequest request);

        /// <summary>
        /// 获取所有普通角色
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <errorCodes>OrganizationCodeIsEmpty</errorCodes>
        /// <returns></returns>
        Task<List<RoleDTO>> FindDefaultRolesAsync(FindDefaultRolesRequest request);

        /// <summary>
        /// 获取所有可认证角色
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns></returns>
        Task<List<RoleDTO>> FindAuthenticationRolesAsync(FindAuthenticationRolesRequest request);
    }
}
