﻿using System.Collections.Generic;
using System.Threading.Tasks;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 短信服务
    /// </summary>
    public interface ISMSService
    {
        /// <summary>
        /// Send message
        /// </summary>
        /// <param name="mobiles"></param>
        /// <param name="template"></param>
        /// <param name="templateArg"></param>
        /// <returns></returns>
        /// <errorCodes>PhoneIncorrect,ExceptionError</errorCodes>
        Task<bool> SendMessageAsync(List<string> mobiles, string template);

        /// <summary>
        /// Check verification code
        /// </summary>
        /// <param name="userPhone"></param>
        /// <param name="verifyCode"></param>
        /// <returns></returns>
        /// <errorCodes>PhoneIncorrect,SMSVerifyCodeIsEmpty,SMSVerifyCodeExpired,SMSVerifyCodeIllegality,ExceptionError</errorCodes>
        Task<bool> CheckVerificationCodeAsync(string userPhone, string verifyCode);  

        /// <summary>
        /// 通用发送短信
        /// </summary>
        /// <param name="mobiles">手机号</param>
        /// <param name="template">模板Id</param>
        /// <param name="paramList">动态参数</param>
        /// <returns></returns>
        /// <errorCodes>PhoneIncorrect,ExceptionError</errorCodes>
        Task<bool> GeneralMessageAsync(List<string> mobiles, string template, List<string> paramList);
    }
}
