﻿using System.Threading.Tasks;
using WingInterfaceLibrary.Request.Storage;
using WingInterfaceLibrary.DTO.Storage;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 文件存储服务接口
    /// </summary>
    /// <docFirstDirectory>公共存储API</docFirstDirectory>
    /// <docSecondDirectory>存储服务</docSecondDirectory>
    public interface IStorageService
    {
        /// <summary>
        /// 上传文件接口
        /// </summary>
        /// <param name="request">上传文件请求实体</param>
        /// <returns>是否成功： True-表示成功，False-表示失败</returns> 
        /// <value>true</value>
        /// <remarks>PUT</remarks>
        Task<bool> UploadFileAsync(StorageRequest request);

        /// <summary>
        /// 上传文件权鉴接口
        /// </summary>
        /// <param name="request">文件上传配置请求实体</param>
        /// <returns>验证后生成的验签信息</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>FileNameIsEmpty</errorCodes>
        Task<StorageServiceSettingDTO> GetAuthorizationAsync(FileServiceRequest request);

        /// <summary>
        /// 远程影像存储服务
        /// </summary>
        /// <param name="request">文件上传配置请求实体</param>
        /// <returns>验证后生成的验签信息</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<StorageServiceSettingDTO> GetStorageTestUrlAsync(CheckStorageRequest request);
    }
}