using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.ServerInfo;
using WingInterfaceLibrary.Request.FastestServer;
using System.Collections.Generic;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 最快服务器响应接口
    /// </summary>
    /// <docFirstDirectory>最快服务器API</docFirstDirectory>
    /// <docSecondDirectory>最快服务器列表及测速服务</docSecondDirectory>
    public interface IVinnoServerService
    {
        /// <summary>
        /// 更新服务器信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <show>false</show>
        Task<bool> UpdateServerInfoAsync(UpdateServerInfoRequest request);

        /// <summary>
        /// 获取服务器信息 
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>服务信息列表</returns>
        Task<List<ServerInfoDTO>> GetServerInfoListAsync(QueryServerInfoRequest request);

        /// <summary>
        /// 测速接口 
        /// </summary>
        /// <returns></returns>
        Task<EchoResult> EchoAsync();

        /// <summary>
        /// 更新服务器IP列表信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <show>false</show>
        Task<bool> UpdateServerIPListAsync(UpdateServerIPListRequest request);

        /// <summary>
        /// 获取密码规则
        /// </summary>
        /// <returns></returns>
        Task<PasswordRuleResult> GetPasswordRuleAsync();
    }
}