using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.OpLog;
using WingInterfaceLibrary.Internal.Request;

namespace WingInterfaceLibrary.Internal.Interface
{
    public interface IMasterInteractionCenterService
    {
        /// <summary>
        /// Get OpLog from master server
        /// </summary>
        /// <param name="request">The request args</param>
        /// <returns>Op log list</returns>
        /// <show>false</show>
        Task<List<OperationLogDTO>> GetOpLogsFromMasterAsync(GetOpLogsFormMasterRequest request);
        
        /// <summary>
        /// Get op logs from master server
        /// </summary>
        /// <param name="request"></param>
        /// <returns>The op log list</returns>
        Task<List<OperationLogDTO>> GetOpLogsByCodesFromMasterAsync(GetOpLogsByCodesFormMasterRequest request);            

        /// <summary>
        /// Sychronize OpLog to master server
        /// </summary>
        /// <param name="request">The request args</param>
        /// <returns>True or false</returns>
        /// <show>false</show>
        Task<bool> SyncOpLogToMasterAsync(SyncOpLogToMasterRequest request);              

        /// <summary>
        /// Sychronize Receive ServiceData for master
        /// </summary>
        /// <returns></returns>
        Task<bool> SyncReceiveSlaveServiceDataAsync(SyncReceiveServiceDataRequest request);
    }
}