﻿using System.Threading.Tasks;
using WingInterfaceLibrary.Request.Notification;
using WingInterfaceLibrary.Internal.Request;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.Internal.Interface
{
    /// <summary>
    /// 通知消息服务
    /// </summary>
    public interface INotificationService
    {
        /// <summary>
        /// 发送通知,等待发送完消息返回是否成功
        /// </summary>
        /// <param name="request">发送通知请求</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> SendMessageAsync(SendNotificationRequest request);

        /// <summary>
        /// 发送通知,消息进入发送队列，返回是否成功进入发送队列
        /// </summary>
        /// <param name="request">发送通知请求</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> PostMessageAsync(SendNotificationRequest request);

        /// <summary>
        /// 群发通知，消息进入发送队列，返回是否成功进入发送队列
        /// </summary>
        /// <param name="request">群发通知请求</param>
        /// <returns>是否成功</returns>
        Task<bool> BroadcastMessageAsync(BroadcastNotificationRequest request);

        /// <summary>
        /// 申请独立队列
        /// </summary>
        /// <param name="request"></param>
        /// <returns>队列标识</returns>
        Task<string> OpenNotifyQueueAsync(OpenNotifyQueueRequest request);

        /// <summary>
        /// 释放队列
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CloseNotifyQueueAsync(CloseNotifyQueueRequest request);

        /// <summary>
        /// 接受到同步的通知消息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<bool> ReceiveSyncServerMessageAsync(SyncReceiveServiceDataRequest request);

        /// <summary>
        /// 移除websocket用户
        /// </summary>
        /// <param name="request">token</param>
        /// <returns>true</returns>
        Task<bool> RemoveToken(TokenRequest request);

        /// <summary>
        /// 移除指定单个websocket连接
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> RemoveSingleTokenAsync(TokenRequest request);
    }
}
