using System;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.OpLog;
using WingInterfaceLibrary.Request.Notification;

namespace WingInterfaceLibrary.Internal.Request
{
    public class SyncReceiveServiceDataRequest
    {
        /// <summary>
        /// 同步对应Service
        /// </summary>
        /// <value></value>
        public SyncServiceEnum SyncService { get; set; }
        /// <summary>
        /// 同步数据类型枚举
        /// </summary>
        /// <value></value>
        public SyncTypeEnum SyncType { get; set; }

        /// <summary>
        /// 业务数据json
        /// </summary>
        /// <value></value>
        public string ServiceDataJson { get; set; } = string.Empty;

        /// <summary>
        /// oplogs
        /// </summary>
        /// <typeparam name="OperationLogDTO"></typeparam>
        /// <returns></returns>
        public IList<OperationLogDTO> Oplogs { get; set; } = new List<OperationLogDTO>();

        /// <summary>
        /// 来自哪个服务器
        /// </summary>
        /// <value></value>
        public string SourceUrl { get; set; } = string.Empty;

        /// <summary>
        ///ServerID
        /// </summary>
        /// <value></value>
        public string ServerID { get; set; } = string.Empty;

        /// <summary>
        /// 通知对象
        /// </summary>
        /// <value></value>
        public SyncNotification Notification { get; set; }

    }

    public class BaseLiveConsultationJson
    {
        /// <summary>
        /// 房间code
        /// </summary>
        /// <value></value>
        public string RoomCode { get; set; } = string.Empty;

        /// <summary>
        /// 预约记录code
        /// </summary>
        /// <value></value>
        public string ConsultationRecordCode { get; set; } = string.Empty;

        /// <summary>
        /// 操作人
        /// </summary>
        /// <value></value>
        public string OperatorCode { get; set; } = string.Empty;

        /// <summary>
        /// 发起人
        /// </summary>
        /// <value></value>
        public string InitatorCode { get; set; } = string.Empty;

        /// <summary>
        /// 需要同步的业务编码
        /// </summary>
        /// <typeparam name="string"></typeparam>
        /// <returns></returns>
        public IList<string> ReferCodes { get; set; } = new List<string>();
        /// <summary>
        /// 用户来源
        /// </summary>
        /// <value></value>
        public LoginSource LoginSource { get; set; }
    }

    public class InitiateLiveConsultationJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// RTC房间号
        /// </summary>
        /// <value></value>
        public int IntegerRoomId { get; set; }

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value></value>
        public string DeviceCode { get; set; }
    }

    /// <summary>
    /// 离开房间
    /// </summary>
    public class LeaveLiveConsultationJson : BaseLiveConsultationJson
    {
        public bool Closed { get; set; }
    }

    /// <summary>
    /// 是否静音会诊
    /// </summary>
    public class MuteLiveConsultationJson : BaseLiveConsultationJson
    {
        public bool Mute { get; set; }
    }

    /// <summary>
    ///是否开启关闭画面会诊
    /// </summary>
    public class SwitchLiveConsultationVideoJson : BaseLiveConsultationJson
    {
        public bool VideoOpend { get; set; }
    }

    public class ChangeConsultationStatusJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// 预约记录状态
        /// </summary>
        /// <value></value>
        public TransactionStatusEnum Status { get; set; }
    }

    public class InviteInLiveConsultationJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// 预约记录状态
        /// </summary>
        /// <value></value>
        public List<string> UserCodes { get; set; } = new List<string>();
    }

    public class CancelInviteInLiveConsultationJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// 预约记录状态
        /// </summary>
        /// <value></value>
        public List<string> UserCodes { get; set; } = new List<string>();
    }

    public class ControllingParameterInLiveConsultationJson : BaseLiveConsultationJson
    {
        public bool IsControllingParameter { get; set; }
    }

    public class EmergencyAcceptLiveConsultationJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// 所属机构
        /// </summary>
        /// <value></value>
        public string OrganizationCode { get; set; } = string.Empty;
    }

    public class SendInteractiveBoardDataConsultationJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value></value>
        public string UserCode { get; set; }

        /// <summary>
        /// 是否清除
        /// </summary>
        /// <value></value>
        public bool IsClear { get; set; }

        /// <summary>
        /// 互动白板数据
        /// </summary>
        public string BoardData { get; set; }

        /// <summary>
        /// 互动时间
        /// </summary>
        /// <value></value>
        public DateTime InteractiveTime { get; set; }
    }

    /// <summary>
    /// 切换会诊房间
    /// </summary>
    public class ChangeConsultationJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// 原先的房间号
        /// </summary>
        /// <value></value>
        public string OriginalRoomId { get; set; } = string.Empty;
        
        /// <summary>
        /// 新的房间号
        /// </summary>
        /// <value></value>
        public string CurrentRoomId { get; set; } = string.Empty;
    }

    /// <summary>
    /// 直播中加入房间
    /// </summary>
    public class JoinInConsultationJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// 排序等级
        /// </summary>
        /// <value></value>
        public int SortLevel { get; set; }
    }

    /// <summary>
    /// 加入房间
    /// </summary>
    public class AgreeInConsultationJson : BaseLiveConsultationJson
    {
        /// <summary>
        /// 排序等级
        /// </summary>
        /// <value></value>
        public int SortLevel { get; set; }
    }

}