using WingInterfaceLibrary.Request;
using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 开始会诊请求实体
    /// </summary>
    public class InitiateLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
    }

    /// <summary>
    /// 开始会诊响应实体
    /// </summary>
    public class InitiateLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 发起人编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string InitiatorCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// Sdk app id
        /// </summary>
        /// <value></value>
        public int AppId { get; set; }

        /// <summary>
        /// User sign for rtc
        /// </summary>
        /// <value>123456</value>
        public string UserSign { get; set; } = string.Empty;

        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();
    }

    /// <summary>
    /// 开始会诊
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class InviteLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 开始会诊的通知
        /// </summary>
        /// <value>11</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.InviteLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 房间编码
        ///  </summary>
        /// <value>1</value>
        public int RoomNo { get; set; }

        /// <summary>
        /// 发起者信息
        /// </summary>
        /// <value></value>
        public LiveConsultationMember Initiator { get; set; }
    }

}
