using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Notifications;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 会诊过程中邀请其他成员请求实体
    /// </summary>
    public class InviteInLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
        /// <summary>
        /// 用户或者设备编码集合
        /// </summary>
        /// <value></value>
        public IList<string> InviteCodes { get; set; }

        /// <summary>
        ///房间号码
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }
    }

    /// <summary>
    /// 会诊过程中邀请其他成员响应实体
    /// </summary>
    public class InviteInLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

    }

    /// <summary>
    /// 会诊过程中邀请他人的通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class InviteInLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 会诊过程中邀请成员的通知
        /// </summary>
        /// <value>8</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.InviteInLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        ///房间号码
        /// </summary>
        /// <value>1</value>
        public int RoomNo { get; set; }

        /// <summary>
        /// 操作者信息
        /// </summary>
        /// <value></value>
        public LiveConsultationMember Operator { get; set; }
        /// <summary>
        /// 会诊成员信息
        /// </summary>
        /// <typeparam name="LiveConsultationMember"></typeparam>
        /// <returns></returns>
        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();
    }

    /// <summary>
    /// 会诊中加入房间通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class JoinInLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举
        /// </summary>
        /// <value>20</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.JoinInLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// The info of who join the diagnosis metting 
        /// </summary>
        /// <value></value>
        public LiveConsultationJoinerInfo Joiner { get; set; }
    }

    /// <summary>
    /// 拒绝会诊中邀请通知
    /// </summary>
    public class RejectInviteLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举
        /// </summary>
        /// <value>17</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.RejectInviteLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 拒绝邀请的人
        /// </summary>
        /// <value></value>
        public LiveConsultationRejecterInfo Rejecter { get; set; }
    }
}