using System.Collections.Generic;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.LiveConsultation.Consultation;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 加入房间请求实体
    /// </summary>
    public class JoinLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 是否呼叫
        /// </summary>
        /// <value>false</value>
        /// <code>0<code>
        public bool NeedCall { get; set; }
    }

    /// <summary>
    /// 加入房间响应实体
    /// </summary>
    public class JoinLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string UserCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// Sdk app id
        /// </summary>
        /// <value></value>
        public int AppId { get; set; }

        /// <summary>
        /// User sign for rtc
        /// </summary>
        /// <value>123456</value>
        public string UserSign { get; set; } = string.Empty;

        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();

        /// <summary>
        /// 互动白板数据集合
        /// </summary>
        /// <typeparam name="InteractiveBoardDataDTO"></typeparam>
        /// <returns></returns>
        public IList<InteractiveBoardDataDTO> InteractiveBoardDatas { get; set; } = new List<InteractiveBoardDataDTO>();
    }
    /// <summary>
    /// 进入会诊
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class JoinLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举
        /// </summary>
        /// <value>17</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.JoinLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// The info of who join the diagnosis metting 
        /// </summary>
        /// <value></value>
        public LiveConsultationJoinerInfo Joiner { get; set; }
    }

    /// <summary>
    /// 设备加入房间响应实体
    /// </summary>
    public class DeviceJoinLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>DeviceDO_123456789</value>
        public string DeviceCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// Sdk app id
        /// </summary>
        /// <value></value>
        public int AppId { get; set; }

        /// <summary>
        /// Device sign for rtc
        /// </summary>
        /// <value>123456</value>
        public string DeviceSign { get; set; } = string.Empty;

        /// <summary>
        /// 直播成员信息-针对设备
        /// </summary>
        /// <value> </value>
        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();

        /// <summary>
        /// 互动白板数据集合
        /// </summary>
        /// <value> </value>
        public IList<InteractiveBoardDataDTO> InteractiveBoardDatas { get; set; } = new List<InteractiveBoardDataDTO>();
    }
    
}
