using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;

namespace WingInterfaceLibrary.Notifications
{
    /// <summary>
    /// 账号被登出通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    /// <notificationDocThirdDirectory>检查更新通知</notificationDocThirdDirectory> 
    public class UpgradeVersionNotification : NotificationDTO
    {
        /// <summary>
        /// 版本更新通知
        /// </summary>
        /// <value>2</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.VersionUpgradeNotification;
        
        /// <summary>
        /// Check the version to check whether it needs to be updated
        /// </summary>
        /// <value>0</value>
        public UpgradeTypeEnum UpgradeType { get; set; }

        /// <summary>
        /// UpgradeUrl cdn
        /// </summary>
        /// <value>http://cdn-bj.fis.plus/B1154C6500E4F174249224B41284498E.zip</value>
        public string UpgradeCDNUrl { get; set; }

        /// <summary>
        /// UpgradeUrl cfs
        /// </summary>
        /// <value>https://flyinsono-bj-1300984704.cos.ap-beijing.myqcloud.com/B1154C6500E4F174249224B41284498E.zip</value>
        public string UpgradeSourceUrl { get; set; }

        /// <summary>
        /// Total or part
        /// </summary>
        /// <value>0</value>
        public UpgradeUpdateTypeEnum UpgradeUpdateType { get; set; }

        /// <summary>
        /// client version
        /// </summary>
        /// <value></value>
        public string NewVersion { get; set; }

        /// <summary>
        /// New version update description
        /// </summary>
        /// <value></value>
        public IList<DescriptionInfoDTO> Descriptions { get; set; }
    }

    /// <summary>
    /// 描述信息实体
    /// </summary>
    public class DescriptionInfoDTO
    {
        /// <summary>
        /// New version update description
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// New version update description
        /// </summary>
        /// <value>zh-CN</value>
        public string LanguageCode { get; set; }
    }
}