using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Message;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.DB.Request
{
    /// <summary>
    /// 添加通知信息
    /// </summary>
    public class AddMessagesDBRequest : MessageInfoDTO
    {

    }

    /// <summary>
    /// 修改通知信息
    /// </summary>
    public class UpdateMessagesDBRequest
    {
        /// <summary>
        /// 客户id (User code , admin code or device code)
        /// </summary>
        public string ClientId { get; set; }

        /// <summary>
        /// 消息code
        /// </summary>
        public string MessageCode { get; set; }

        /// <summary>
        /// 是否已读：默认false-表示未读
        /// </summary>
        public bool IsReaded { get; set; }
    }

    /// <summary>
    /// 根据用户编码批量更新消息状态
    /// </summary>
    public class UpdateMessagesStatusDBequest
    {
        /// <summary>
        /// 客户id (User code , admin code or device code)
        /// </summary>
        public string ClientId { get; set; }

        /// <summary>
        /// 消息列表
        /// </summary>
        public IList<string> MessageCodes { get; set; }
    }

    /// <summary>
    /// 通过UserCode获取消息列表
    /// </summary>
    public class GetMessagesDBPageRequest : PageFilterRequest
    {
        /// <summary>
        /// 客户id (User code , admin code or device code)
        /// </summary>
        public string ClientId { get; set; }

        /// <summary>
        /// 查询消息状态
        /// </summary>
        /// <value></value>
        public QueryCMSMessageStatusEnum Status { get; set; }

        /// <summary>
        /// 关键字
        /// </summary>
        /// <value></value>
        public string Keyword { get; set; }

        /// <summary>
        /// 开始时间【创建时间】
        /// </summary>
        /// <value>2022-02-28T09:21:38.861Z</value>
        public DateTime StartTime { get; set; }

        /// <summary>
        /// 截至时间【创建时间】
        /// </summary>
        /// <value>2022-03-28T09:21:38.861Z</value>
        public DateTime EndTime { get; set; }

        /// <summary>
        /// 通知类型
        /// </summary>
        /// <value>1</value>
        public List<NotificationTypeEnum> NotificationTypes { get; set; }

        /// <summary>
        /// 关联业务编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string RelevanceCode { get; set; }
    }

    /// <summary>
    /// 通过UserCode获取消息列表
    /// </summary>
    public class FindMessagesDBRequest
    {
        /// <summary>
        /// 客户id (User code , admin code or device code)
        /// </summary>
        public string ClientId { get; set; }

        /// <summary>
        /// 通知类型
        /// </summary>
        /// <value>1</value>
        public List<NotificationTypeEnum> NotificationTypes { get; set; }

        /// <summary>
        /// 关联业务编码
        /// </summary>
        /// <value>4914352a75f645279f6b4ad6764cc288</value>
        public string RelevanceCode { get; set; }

        /// <summary>
        /// 接收方类型【客户端、设备端】
        /// </summary>
        /// <value>0</value>
        public ApplicantTypeEnum ReceiverType { get; set; }

        /// <summary>
        /// 业务类型【会诊、聊天会话、公告】
        /// </summary>
        /// <value>0</value>
        public TransactionTypeEnum TransactionType  { get; set; }
    }


    /// <summary>
    /// 获取未读消息数量请求
    /// </summary>
    public class GetNoReadMessagesDBRequest
    {
        /// <summary>
        /// 客户id (User code , admin code or device code)
        /// </summary>
        public string ClientId { get; set; }

        /// <summary>
        /// 通知类型
        /// </summary>
        /// <value>1</value>
        public List<NotificationTypeEnum> NotificationTypes { get; set; }
    }
}