using System.Collections.Generic;
using WingInterfaceLibrary.DTO.LiveRoom;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.CommentEnum;
using WingInterfaceLibrary.LiveConsultation;

namespace WingInterfaceLibrary.DB.Request
{
    /// <summary>
    /// 保存用户直播状态请求实体
    /// </summary>
    public class AddOrUpdateLiveMemberDBRequest
    {
        /// <summary>
        /// 房间编码
        /// </summary>
        /// <value>fb6414d24e3c347d46032b0496f1c4e4</value>
        public string LiveRoomCode { get; set; } = string.Empty;

        /// <summary>
        /// 设备/用户编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string MemberCode { get; set; } = string.Empty;

        /// <summary>
        /// 成员类型
        /// </summary>
        /// <value>UserDO_123456789</value>
        public LiveMemberEnum MemberType { get; set; }

        /// <summary>
        /// 设备/用户姓名
        /// </summary>
        /// <value>刘医生</value>
        public string Name { get; set; } = string.Empty;

        /// <summary>
        /// 头像
        /// </summary>
        /// <value></value>
        public string HeadImageToken { get; set; }
        
        /// <summary>
        /// 状态
        /// </summary>
        public LiveMemberStatus Status { get; set; }

        /// <summary>
        /// 是否静音
        /// </summary>
        /// <value>false</value>
        public bool MuteOpened { get; set; } = false;

        /// <summary>
        /// 是否参与者
        /// </summary>
        /// <value>false</value>
        public bool IsExpertUser { get; set; } = false;
        
        /// <summary>
        /// 是否助理
        /// </summary>
        /// <value>false</value>
        public bool IsAssistantUser { get; set; } = false;

        /// <summary>
        /// 是否开启视频
        /// </summary>
        /// <value>false</value>
        public bool VideoOpened {get;set;}

        /// <summary>
        /// 连接服务器地址
        /// </summary>
        /// <value>http://api2.flyinsono.com/</value>
        public string LoginServerHost { get; set; } = string.Empty;

        /// <summary>
        /// 直播信息
        /// </summary>
        /// <value></value>
        public LiveDataDTO LiveData { get; set; }

        /// <summary>
        /// 是否正在控制参数
        /// </summary>
        /// <value></value>
        public bool  IsControllingParameter{ get; set; }

        /// <summary>
        /// 房间状态
        /// </summary>
        /// <value></value>
        public LiveRoomStatus RoomStatus{ get; set; }
        
        /// <summary>
        /// 排序等级
        /// </summary>
        /// <value></value>
        public int SortLevel { get; set; }
        
        /// <summary>
        /// 设备画面信息
        /// </summary>
        /// <typeparam name="VideoDeviceInfoDO"></typeparam>
        /// <returns></returns>
        public List<VideoDeviceInfoDTO> VideoDeviceInfos { get; set; } = new List<VideoDeviceInfoDTO>();
        
        /// <summary>
        /// 用户来源
        /// </summary>
        /// <value></value>
        public LoginSource LoginSource { get; set; }
    }
}
